@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: cae_alsa.cpp,v 1.34 2007/09/14 14:06:23 fredg Exp $
+//      $Id: cae_alsa.cpp,v 1.38 2007/12/26 17:44:03 grauf Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -27,7 +27,9 @@
 
 #include <qsignalmapper.h>
 
+#include <rd.h>
 #include <rdringbuffer.h>
+#include <rdmeteraverage.h>
 
 #include <cae.h>
 
@@ -37,8 +39,8 @@
 //
 volatile int alsa_input_channels[RD_MAX_CARDS][RD_MAX_PORTS];
 volatile int alsa_output_channels[RD_MAX_CARDS][RD_MAX_STREAMS];
-volatile double alsa_input_meter[RD_MAX_CARDS][RD_MAX_PORTS][2];
-volatile double alsa_output_meter[RD_MAX_CARDS][RD_MAX_PORTS][2];
+RDMeterAverage *alsa_input_meter[RD_MAX_CARDS][RD_MAX_PORTS][2];
+RDMeterAverage *alsa_output_meter[RD_MAX_CARDS][RD_MAX_PORTS][2];
 volatile double alsa_input_volume[RD_MAX_CARDS][RD_MAX_PORTS];
 volatile double alsa_output_volume[RD_MAX_CARDS][RD_MAX_PORTS][RD_MAX_STREAMS];
 volatile double 
@@ -69,7 +71,7 @@ void AlsaCapture2Callback(struct alsa_format *alsa_format)
 
   while(!alsa_format->exiting) {
     int s=snd_pcm_readi(alsa_format->pcm,alsa_format->card_buffer,
-			ALSA_PERIOD_SIZE/(alsa_format->periods*2));
+			rd_config->alsaPeriodSize()/(alsa_format->periods*2));
     if((snd_pcm_state(alsa_format->pcm)!=SND_PCM_STATE_RUNNING)&&
        (!alsa_format->exiting)) {
       snd_pcm_drop (alsa_format->pcm);
@@ -157,8 +159,8 @@ void AlsaCapture2Callback(struct alsa_format *alsa_format)
 		       card_buffer)[alsa_format->channels*k+2*i+j];
 		  }
 		}
-		alsa_input_meter[alsa_format->card][i/2][j]=
-		  ((double)in_meter[i/2][j])/32768.0;
+		alsa_input_meter[alsa_format->card][i/2][j]->
+		  addValue(((double)in_meter[i/2][j])/32768.0);
 	      }
 	    }
 	    break;
@@ -234,8 +236,8 @@ void AlsaCapture2Callback(struct alsa_format *alsa_format)
 		       card_buffer)[alsa_format->channels*2*k+2*i+1+2*j];
 		  }
 		}
-		alsa_input_meter[alsa_format->card][i/2][j]=
-		  ((double)in_meter[i/2][j])/32768.0;
+		alsa_input_meter[alsa_format->card][i/2][j]->
+		  addValue(((double)in_meter[i/2][j])/32768.0);
 	      }
 	    }
 	    break;
@@ -382,10 +384,10 @@ void AlsaPlay2Callback(struct alsa_format *alsa_format)
 		     card_buffer)[alsa_format->channels*k+2*i+1+j];
 		}
 	      }
-	      alsa_output_meter[alsa_format->card][i][j]=
-		((double)out_meter[i][j])/32768.0;
-	      alsa_output_meter[alsa_format->card][i+1][j]=
-		((double)out_meter[i+1][j])/32768.0;
+	      alsa_output_meter[alsa_format->card][i][j]->
+		addValue(((double)out_meter[i][j])/32768.0);
+	      alsa_output_meter[alsa_format->card][i+1][j]->
+		addValue(((double)out_meter[i+1][j])/32768.0);
 	    }
 	  }
 	  break;
@@ -490,10 +492,10 @@ void AlsaPlay2Callback(struct alsa_format *alsa_format)
 		     card_buffer)[alsa_format->channels*2*k+4*i+3+2*j];
 		}
 	      }
-	      alsa_output_meter[alsa_format->card][i][j]=
-		((double)out_meter[i][j])/32768.0;
-	      alsa_output_meter[alsa_format->card][i+1][j]=
-		((double)out_meter[i+1][j])/32768.0;
+	      alsa_output_meter[alsa_format->card][i][j]->
+		addValue(((double)out_meter[i][j])/32768.0);
+	      alsa_output_meter[alsa_format->card][i+1][j]->
+		addValue(((double)out_meter[i+1][j])/32768.0);
 	    }
 	  }
 	  break;
@@ -543,6 +545,8 @@ void *AlsaPlayCallback(void *ptr)
 
 void MainObject::AlsaInitCallback()
 {
+  int avg_periods=
+    (330*rd_config->sampleRate())/(1000*rd_config->alsaPeriodSize());
   for(int i=0;i<RD_MAX_CARDS;i++) {
     for(int j=0;j<RD_MAX_PORTS;j++) {
       alsa_recording[i][j]=false;
@@ -550,8 +554,8 @@ void MainObject::AlsaInitCallback()
       alsa_input_volume[i][j]=1.0;
       alsa_input_vox[i][j]=0.0;
       for(int k=0;k<2;k++) {
-	alsa_input_meter[i][j][k]=0.0;
-	alsa_output_meter[i][j][k]=0.0;
+	alsa_input_meter[i][j][k]=new RDMeterAverage(avg_periods);
+	alsa_output_meter[i][j][k]=new RDMeterAverage(avg_periods);
       }
       for(int k=0;k<RD_MAX_STREAMS;k++) {
 	alsa_output_volume[i][j][k]=1.0;
@@ -693,9 +697,13 @@ void MainObject::alsaInit(RDStation *station)
   for(int i=0;i<RD_MAX_CARDS;i++) {
     if(cae_driver[i]==RDStation::None) {
       pcm_opened=false;
+      // These are used to flag bits of card that are not setup
+      // They are cleared just before the pthreads are created.
+      alsa_play_format[i].exiting = true;
+      alsa_capture_format[i].exiting = true;
       dev=QString().sprintf("rd%d",card);
       if(snd_pcm_open(&pcm_play_handle,(const char *)dev,
-		      SND_PCM_STREAM_PLAYBACK,0)==0) {
+		      SND_PCM_STREAM_PLAYBACK,0)==0){
 	pcm_opened=true;
 	if(AlsaStartPlayDevice(dev,i,pcm_play_handle)) {
 	  cae_driver[i]=RDStation::Alsa;
@@ -766,11 +774,18 @@ void MainObject::alsaFree()
 bool MainObject::alsaLoadPlayback(int card,QString wavename,int *stream)
 {
 #ifdef ALSA
-  if((*stream=GetAlsaOutputStream(card))<0) {
+  if(alsa_play_format[card].exiting || ((*stream=GetAlsaOutputStream(card))<0)) {
+    LogLine(QString().sprintf(
+            "Error: alsaLoadPlayback(%s) GetAlsaOutputStream():%d < 0",
+            (const char *) wavename,
+            *stream) );
     return false;
   }
   alsa_play_wave[card][*stream]=new RDWaveFile(wavename);
   if(!alsa_play_wave[card][*stream]->openWave()) {
+    LogLine(QString().sprintf(
+            "Error: alsaLoadPlayback(%s)   openWave() failed to open file",
+            (const char *) wavename) );
     delete alsa_play_wave[card][*stream];
     alsa_play_wave[card][*stream]=NULL;
     FreeAlsaOutputStream(card,*stream);
@@ -779,6 +794,11 @@ bool MainObject::alsaLoadPlayback(int card,QString wavename,int *stream)
   }
   if((alsa_play_wave[card][*stream]->getFormatTag()!=WAVE_FORMAT_PCM)||
      (alsa_play_wave[card][*stream]->getBitsPerSample()!=16)) {
+    LogLine(QString().sprintf(
+            "Error: alsaLoadPlayback(%s)   getFormatTag()%d || getBistsPerSample()%d failed",
+            (const char *) wavename,
+            alsa_play_wave[card][*stream]->getFormatTag(),
+            alsa_play_wave[card][*stream]->getBitsPerSample() ));
     delete alsa_play_wave[card][*stream];
     alsa_play_wave[card][*stream]=NULL;
     FreeAlsaOutputStream(card,*stream);
@@ -820,7 +840,8 @@ bool MainObject::alsaUnloadPlayback(int card,int stream)
 bool MainObject::alsaPlaybackPosition(int card,int stream,unsigned pos)
 {
 #ifdef ALSA
-  if(alsa_playing[card][stream]) {
+  if(alsa_play_format[card].exiting){
+    return false;
   }
   alsa_play_ring[card][stream]->reset();
   unsigned offset=
@@ -1024,8 +1045,8 @@ bool MainObject::alsaFadeOutputVolume(int card,int stream,int port,int level,
   }
   alsa_fade_volume_db[card][stream]=level;
   alsa_fade_port[card][stream]=port;
-  alsa_fade_increment[card][stream]=diff*ALSA_FADE_INTERVAL/length;
-  alsa_fade_timer[card][stream]->start(ALSA_FADE_INTERVAL);
+  alsa_fade_increment[card][stream]=diff*RD_ALSA_FADE_INTERVAL/length;
+  alsa_fade_timer[card][stream]->start(RD_ALSA_FADE_INTERVAL);
   return true;
 #else
   return false;
@@ -1110,7 +1131,7 @@ bool MainObject::alsaGetInputMeters(int card,int port,short levels[2])
 
   for(int i=0;i<2;i++) {
 
-    meter=alsa_input_meter[card][port][i];
+    meter=alsa_input_meter[card][port][i]->average();
     if(meter==0.0) {
       levels[i]=-10000;
     }
@@ -1134,7 +1155,7 @@ bool MainObject::alsaGetOutputMeters(int card,int port,short levels[2])
   double meter;
 
   for(int i=0;i<2;i++) {
-    meter=alsa_output_meter[card][port][i];
+    meter=alsa_output_meter[card][port][i]->average();
     if(meter==0.0) {
       levels[i]=-10000;
     }
@@ -1156,9 +1177,13 @@ void MainObject::alsaGetOutputPosition(int card,unsigned *pos)
 {// pos is in miliseconds
 #ifdef ALSA
   for(int i=0;i<RD_MAX_STREAMS;i++) {
-    pos[i]=(((unsigned long long)(alsa_offset[card][i]+
-				  alsa_output_pos[card][i]))* 
-	    1000)/alsa_play_format[card].sample_rate;
+    if (!alsa_play_format[card].exiting){
+      pos[i]=(((unsigned long long)(alsa_offset[card][i]+
+				    alsa_output_pos[card][i]))* 
+	      1000)/alsa_play_format[card].sample_rate;
+    } else {
+      pos = 0;
+    }
   }
 #endif  // ALSA
 }
@@ -1240,11 +1265,11 @@ bool MainObject::AlsaStartCaptureDevice(QString &dev,int card,snd_pcm_t *pcm)
     sr=alsa_play_format[card].sample_rate;
   }
   else {
-    sr=rd_config->sampleRate();;
+    sr=rd_config->sampleRate();
   }
   snd_pcm_hw_params_set_rate_near(pcm,hwparams,&sr,&dir);
-  if((sr>(rd_config->sampleRate()-ALSA_SAMPLE_RATE_TOLERANCE))&&
-     (sr<(rd_config->sampleRate()+ALSA_SAMPLE_RATE_TOLERANCE))) {
+  if((sr>(rd_config->sampleRate()-RD_ALSA_SAMPLE_RATE_TOLERANCE))&&
+     (sr<(rd_config->sampleRate()+RD_ALSA_SAMPLE_RATE_TOLERANCE))) {
     sr=rd_config->sampleRate();
   }
   alsa_capture_format[card].sample_rate=sr;
@@ -1263,13 +1288,13 @@ bool MainObject::AlsaStartCaptureDevice(QString &dev,int card,snd_pcm_t *pcm)
   //
   // Buffer Size
   //
-  alsa_capture_format[card].periods=ALSA_PERIOD_QUANTITY;
+  alsa_capture_format[card].periods=rd_config->alsaPeriodQuantity();
   snd_pcm_hw_params_set_periods_near(pcm,hwparams,
 				     &alsa_capture_format[card].periods,&dir);
   LogLine(QString().sprintf("  Periods = %u",
 			    alsa_capture_format[card].periods));
   alsa_capture_format[card].buffer_size=
-    alsa_capture_format[card].periods*ALSA_PERIOD_SIZE;
+    alsa_capture_format[card].periods*rd_config->alsaPeriodSize();
   snd_pcm_hw_params_set_buffer_size_near(pcm,hwparams,
 	       			 &alsa_capture_format[card].buffer_size);
   LogLine(QString().
@@ -1308,14 +1333,12 @@ bool MainObject::AlsaStartCaptureDevice(QString &dev,int card,snd_pcm_t *pcm)
     new char[alsa_capture_format[card].card_buffer_size];
   alsa_capture_format[card].pcm=pcm;
   alsa_capture_format[card].card=card;
-  alsa_capture_format[card].exiting=false;
-
   //
   // Set Wake-up Timing
   //
   snd_pcm_sw_params_alloca(&swparams);
   snd_pcm_sw_params_current(pcm,swparams);
-  snd_pcm_sw_params_set_avail_min(pcm,swparams,ALSA_PERIOD_SIZE);
+  snd_pcm_sw_params_set_avail_min(pcm,swparams,rd_config->alsaPeriodSize());
   if((err=snd_pcm_sw_params(pcm,swparams))<0) {
     LogLine(QString().sprintf("ALSA Device %s: %s",
 			      (const char *)dev,
@@ -1332,6 +1355,7 @@ bool MainObject::AlsaStartCaptureDevice(QString &dev,int card,snd_pcm_t *pcm)
     pthread_attr_setschedpolicy(&pthread_attr,SCHED_FIFO);
   }
 */
+  alsa_capture_format[card].exiting = false;
   pthread_create(&alsa_capture_format[card].thread,&pthread_attr,
 		 AlsaCaptureCallback,&alsa_capture_format[card]);
   return true;
@@ -1391,8 +1415,8 @@ bool MainObject::AlsaStartPlayDevice(QString &dev,int card,snd_pcm_t *pcm)
   //
   sr=rd_config->sampleRate();
   snd_pcm_hw_params_set_rate_near(pcm,hwparams,&sr,&dir);
-  if((sr>(rd_config->sampleRate()-ALSA_SAMPLE_RATE_TOLERANCE))&&
-     (sr<(rd_config->sampleRate()+ALSA_SAMPLE_RATE_TOLERANCE))) {
+  if((sr>(rd_config->sampleRate()-RD_ALSA_SAMPLE_RATE_TOLERANCE))&&
+     (sr<(rd_config->sampleRate()+RD_ALSA_SAMPLE_RATE_TOLERANCE))) {
     sr=rd_config->sampleRate();
   }
   alsa_play_format[card].sample_rate=sr;
@@ -1410,12 +1434,12 @@ bool MainObject::AlsaStartPlayDevice(QString &dev,int card,snd_pcm_t *pcm)
   //
   // Buffer Size
   //
-  alsa_play_format[card].periods=ALSA_PERIOD_QUANTITY;
+  alsa_play_format[card].periods=rd_config->alsaPeriodQuantity();
   snd_pcm_hw_params_set_periods_near(pcm,hwparams,
 				     &alsa_play_format[card].periods,&dir);
   LogLine(QString().sprintf("  Periods = %u",alsa_play_format[card].periods));
   alsa_play_format[card].buffer_size=
-    alsa_play_format[card].periods*ALSA_PERIOD_SIZE;
+    alsa_play_format[card].periods*rd_config->alsaPeriodSize();
   snd_pcm_hw_params_set_buffer_size_near(pcm,hwparams,
 					 &alsa_play_format[card].buffer_size);
   LogLine(QString().
@@ -1452,14 +1476,13 @@ bool MainObject::AlsaStartPlayDevice(QString &dev,int card,snd_pcm_t *pcm)
     new char[alsa_play_format[card].card_buffer_size];
   alsa_play_format[card].pcm=pcm;
   alsa_play_format[card].card=card;
-  alsa_play_format[card].exiting=false;
 
   //
   // Set Wake-up Timing
   //
   snd_pcm_sw_params_alloca(&swparams);
   snd_pcm_sw_params_current(pcm,swparams);
-  snd_pcm_sw_params_set_avail_min(pcm,swparams,ALSA_PERIOD_SIZE);
+  snd_pcm_sw_params_set_avail_min(pcm,swparams,rd_config->alsaPeriodSize());
   if((err=snd_pcm_sw_params(pcm,swparams))<0) {
     LogLine(QString().sprintf("ALSA Device %s: %s",
 			      (const char *)dev,
@@ -1476,6 +1499,7 @@ bool MainObject::AlsaStartPlayDevice(QString &dev,int card,snd_pcm_t *pcm)
     pthread_attr_setschedpolicy(&pthread_attr,SCHED_FIFO);
   }
   */
+  alsa_play_format[card].exiting = false;
   pthread_create(&alsa_play_format[card].thread,&pthread_attr,
 		 AlsaPlayCallback,&alsa_play_format[card]);
   return true;
