@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: cae_hpi.cpp,v 1.30 2007/09/14 14:06:23 fredg Exp $
+//      $Id: cae_hpi.cpp,v 1.31 2007/12/26 17:44:03 grauf Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -60,6 +60,9 @@ bool MainObject::hpiLoadPlayback(int card,QString wavename,int *stream)
   RDHPIPlayStream *playstream=new RDHPIPlayStream(sound_card);
   playstream->setCard(card);
   if(playstream->openWave(wavename)!=RDHPIPlayStream::Ok) {
+    LogLine(QString().sprintf(
+            "Error: hpiLoadPlayback(%s)   openWave() failed to open file",
+            (const char *) wavename) );
     delete playstream;
     return false;
   }
