@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdconfig.cpp,v 1.14 2007/09/14 14:06:24 fredg Exp $
+//      $Id: rdconfig.cpp,v 1.17 2007/12/31 18:49:08 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -33,6 +33,17 @@
 #include <rdconfig.h>
 
 
+RDConfig *RDConfiguration(void) 
+{
+  static RDConfig *config = NULL;
+  if (!config){
+    config = new RDConfig();
+    config->load();
+  }
+  return config;
+}
+
+
 RDConfig::RDConfig()
 {
   clear();
@@ -57,6 +68,21 @@ void RDConfig::setFilename(QString filename)
   conf_filename=filename;
 }
 
+QString RDConfig::audioRoot() const
+{
+  return conf_audio_root;
+}
+
+QString RDConfig::audioExtension() const
+{
+  return conf_audio_extension;
+}
+
+QString RDConfig::audioFileName (QString cutname)
+{
+  return audioRoot() + QString("/") + cutname + QString(".") +
+    audioExtension();
+};
 
 QString RDConfig::mysqlHostname() const
 {
@@ -94,6 +120,18 @@ int RDConfig::mysqlHeartbeatInterval() const
 }
 
 
+int RDConfig::alsaPeriodQuantity() const
+{
+  return conf_alsa_period_quantity;
+}
+
+
+int RDConfig::alsaPeriodSize() const
+{
+  return conf_alsa_period_size;
+}
+
+
 QString RDConfig::stationName() const
 {
   return conf_station_name;
@@ -259,6 +297,10 @@ void RDConfig::load()
     profile->stringValue("Identity","AudioOwner",RD_DEFAULT_AUDIO_OWNER);
   conf_audio_group=
     profile->stringValue("Identity","AudioGroup",RD_DEFAULT_AUDIO_GROUP);
+  conf_audio_root=
+    profile->stringValue("Cae","AudioRoot",RD_AUDIO_ROOT);
+  conf_audio_extension=
+    profile->stringValue("Cae","AudioExtension",RD_AUDIO_EXTENSION);
   conf_mysql_hostname=
     profile->stringValue("mySQL","Hostname",DEFAULT_MYSQL_HOSTNAME);
   conf_mysql_username=
@@ -271,6 +313,10 @@ void RDConfig::load()
   conf_mysql_heartbeat_interval=
     profile->intValue("mySQL","HeartbeatInterval",
 		      DEFAULT_MYSQL_HEARTBEAT_INTERVAL);
+  conf_alsa_period_quantity=
+    profile->intValue("Alsa","PeriodQuantity",RD_ALSA_DEFAULT_PERIOD_QUANTITY);
+  conf_alsa_period_size=
+    profile->intValue("Alsa","PeriodSize",RD_ALSA_DEFAULT_PERIOD_SIZE);
   conf_ripcd_logname=profile->stringValue("Ripcd","Logfile","");
   conf_airplay_logname=profile->stringValue("RDAirPlay","Logfile","");
   conf_catchd_logname=profile->stringValue("RDCatchd","Logfile","");
@@ -323,10 +369,14 @@ void RDConfig::clear()
   conf_mysql_password="";
   conf_mysql_driver="";
   conf_mysql_heartbeat_interval=DEFAULT_MYSQL_HEARTBEAT_INTERVAL;
+  conf_alsa_period_quantity=RD_ALSA_DEFAULT_PERIOD_QUANTITY;
+  conf_alsa_period_size=RD_ALSA_DEFAULT_PERIOD_SIZE;
   conf_station_name="";
   conf_password="";
   conf_audio_owner="";
   conf_audio_group="";
+  conf_audio_root=RD_AUDIO_ROOT;
+  conf_audio_extension=RD_AUDIO_EXTENSION;
   conf_ripcd_logname="";
   conf_airplay_logname="";
   conf_catchd_logname="";
