@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rddropbox.cpp,v 1.3 2007/09/14 14:06:24 fredg Exp $
+//      $Id: rddropbox.cpp,v 1.4 2007/10/04 20:53:28 dmills Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,6 +20,7 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
+#include <rddb.h>
 #include <rdconf.h>
 #include <rddropbox.h>
 
@@ -29,7 +30,7 @@
 //
 RDDropbox::RDDropbox(int id,const QString &stationname)
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   box_id=id;
@@ -37,10 +38,10 @@ RDDropbox::RDDropbox(int id,const QString &stationname)
   if(id<0) {
     sql=QString().sprintf("insert into DROPBOXES set STATION_NAME=\"%s\"",
 			  (const char *)stationname);
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     delete q;
     sql="select ID from DROPBOXES order by ID desc";
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     if(q->first()) {
       box_id=q->value(0).toInt();
     }
@@ -216,48 +217,48 @@ void RDDropbox::setLogPath(const QString &path) const
 
 void RDDropbox::SetRow(QString param,int value) const
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   sql=QString().sprintf("update DROPBOXES set %s=%d where ID=%d",
 			(const char *)param,value,box_id);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 }
 
 
 void RDDropbox::SetRow(QString param,unsigned value) const
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   sql=QString().sprintf("update DROPBOXES set %s=%u where ID=%d",
 			(const char *)param,value,box_id);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 }
 
 
 void RDDropbox::SetRow(QString param,QString value) const
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   sql=QString().sprintf("update DROPBOXES set %s=\"%s\" where ID=%d",
 			(const char *)param,(const char *)value,box_id);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 }
 
 
 void RDDropbox::SetRow(QString param,bool value) const
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   sql=QString().sprintf("update DROPBOXES set %s=\"%s\" where ID=%d",
 			(const char *)param,(const char *)RDYesNo(value),
 			box_id);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 }
