@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdexport_settings_dialog.cpp,v 1.7 2007/09/14 14:06:24 fredg Exp $
+//      $Id: rdexport_settings_dialog.cpp,v 1.9 2007/10/18 15:42:13 dmills Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -82,6 +82,8 @@ RDExportSettingsDialog::RDExportSettingsDialog(RDSettings *settings,
   //
   lib_samprate_box=new QComboBox(this,"lib_samprate_box");
   lib_samprate_box->setGeometry(100,54,100,19);
+  connect(lib_samprate_box,SIGNAL(activated(const QString &)),
+	  this,SLOT(samprateData(const QString &)));
   QLabel *lib_samprate_label=
     new QLabel(lib_samprate_box,tr("&Sample Rate:"),this,
 	       "lib_samprate_label");
@@ -163,24 +165,19 @@ RDExportSettingsDialog::RDExportSettingsDialog(RDSettings *settings,
   lib_channels_box->insertItem("1");
   lib_channels_box->insertItem("2");
   lib_channels_box->setCurrentItem(lib_settings->channels()-1);
+  lib_samprate_box->insertItem("16000");
+  lib_samprate_box->insertItem("22050");
+  lib_samprate_box->insertItem("24000");
   lib_samprate_box->insertItem("32000");
   lib_samprate_box->insertItem("44100");
   lib_samprate_box->insertItem("48000");
-  switch(lib_settings->sampleRate()) {
-      case 32000:
-	lib_samprate_box->setCurrentItem(0);
-	break;
-
-      case 44100:
-	lib_samprate_box->setCurrentItem(1);
-	break;
-
-      case 48000:
-	lib_samprate_box->setCurrentItem(2);
-	break;
+  for(int i=0;i<lib_samprate_box->count();i++) {
+    if(lib_samprate_box->text(i).toUInt()==lib_settings->sampleRate()) {
+      lib_samprate_box->setCurrentItem(i);
+    }
   }
-  ShowBitRates(lib_settings->format(),lib_settings->bitRate(),
-	       lib_settings->quality());
+  ShowBitRates(lib_settings->format(),lib_settings->sampleRate(),
+	       lib_settings->bitRate(),lib_settings->quality());
 }
 
 
@@ -214,10 +211,18 @@ void RDExportSettingsDialog::formatData(const QString &str)
   if(!ok) {
     bitrate=0;
   }
-  ShowBitRates(fmt,bitrate,lib_quality_spin->value());
+  ShowBitRates(fmt,lib_samprate_box->currentText().toInt(),
+	       bitrate,lib_quality_spin->value());
 }
 
 
+void RDExportSettingsDialog::samprateData(const QString &str)
+{
+  ShowBitRates(GetFormat(lib_format_box->currentText()),str.toInt(),
+	       lib_bitrate_box->currentText().replace("kbps","").toInt(),
+	       lib_quality_spin->value());
+}
+
 void RDExportSettingsDialog::bitrateData(const QString &str)
 {
   lib_quality_label->setEnabled(str==tr("VBR"));
@@ -241,7 +246,9 @@ void RDExportSettingsDialog::okData()
       case RDSettings::MpegL1:
       case RDSettings::MpegL2:
       case RDSettings::MpegL3:
-	sscanf(lib_bitrate_box->currentText(),"%d",&rate);
+	if (lib_bitrate_box && lib_bitrate_box->currentText()){
+	  sscanf(lib_bitrate_box->currentText(),"%d",&rate);
+	}
 	if(rate!=0) {
 	  lib_settings->setBitRate(1000*rate);
 	  lib_settings->setQuality(0);
@@ -274,8 +281,8 @@ void RDExportSettingsDialog::cancelData()
 }
 
 
-void RDExportSettingsDialog::ShowBitRates(RDSettings::Format fmt,
-					  int rate,int qual)
+void RDExportSettingsDialog::ShowBitRates(RDSettings::Format fmt,int samprate,
+					  int bitrate,int qual)
 {
   lib_bitrate_box->clear();
   switch(fmt) {
@@ -304,7 +311,7 @@ void RDExportSettingsDialog::ShowBitRates(RDSettings::Format fmt,
 	lib_bitrate_box->insertItem(tr("416 kbps"));
 	lib_bitrate_box->insertItem(tr("448 kbps"));
 	lib_bitrate_box->insertItem(tr("VBR"));
-	switch(rate) {
+	switch(bitrate) {
 	    case 0:
 	      lib_bitrate_box->setCurrentItem(14);
 	      lib_quality_spin->setEnabled(true);
@@ -416,7 +423,7 @@ void RDExportSettingsDialog::ShowBitRates(RDSettings::Format fmt,
 	lib_bitrate_box->insertItem(tr("256 kbps"));
 	lib_bitrate_box->insertItem(tr("320 kbps"));
 	lib_bitrate_box->insertItem(tr("384 kbps"));
-	switch(rate) {
+	switch(bitrate) {
 	    case 0:
 	      lib_bitrate_box->setCurrentItem(11);
 	      lib_quality_spin->setDisabled(true);
@@ -512,112 +519,232 @@ void RDExportSettingsDialog::ShowBitRates(RDSettings::Format fmt,
       case RDSettings::MpegL3:  // MPEG-1 Layer 3
 	lib_bitrate_box->setEnabled(true);
 	lib_bitrate_label->setEnabled(true);
-	lib_bitrate_box->insertItem(tr("32 kbps"));
-	lib_bitrate_box->insertItem(tr("40 kbps"));
-	lib_bitrate_box->insertItem(tr("48 kbps"));
-	lib_bitrate_box->insertItem(tr("56 kbps"));
-	lib_bitrate_box->insertItem(tr("64 kbps"));
-	lib_bitrate_box->insertItem(tr("80 kbps"));
-	lib_bitrate_box->insertItem(tr("96 kbps"));
-	lib_bitrate_box->insertItem(tr("112 kbps"));
-	lib_bitrate_box->insertItem(tr("128 kbps"));
-	lib_bitrate_box->insertItem(tr("160 kbps"));
-	lib_bitrate_box->insertItem(tr("192 kbps"));
-	lib_bitrate_box->insertItem(tr("224 kbps"));
-	lib_bitrate_box->insertItem(tr("256 kbps"));
-	lib_bitrate_box->insertItem(tr("320 kbps"));
-	lib_bitrate_box->insertItem(tr("VBR"));
-	switch(rate) {
-	    case 0:
-	      lib_bitrate_box->setCurrentItem(14);
-	      lib_quality_spin->setEnabled(true);
-	      lib_quality_label->setEnabled(true);
-	      lib_quality_spin->setRange(0,9);
-	      lib_quality_spin->setValue(qual);
-	      break;
-
+	switch(samprate) {
 	    case 32000:
-	      lib_bitrate_box->setCurrentItem(0);
-	      lib_quality_spin->setDisabled(true);
-	      lib_quality_label->setDisabled(true);
-	      break;
-
-	    case 40000:
-	      lib_bitrate_box->setCurrentItem(1);
-	      lib_quality_spin->setDisabled(true);
-	      lib_quality_label->setDisabled(true);
-	      break;
-
+	    case 44100:
 	    case 48000:
-	      lib_bitrate_box->setCurrentItem(2);
-	      lib_quality_spin->setDisabled(true);
-	      lib_quality_label->setDisabled(true);
+	    default:
+	      lib_bitrate_box->insertItem(tr("32 kbps"));
+	      lib_bitrate_box->insertItem(tr("40 kbps"));
+	      lib_bitrate_box->insertItem(tr("48 kbps"));
+	      lib_bitrate_box->insertItem(tr("56 kbps"));
+	      lib_bitrate_box->insertItem(tr("64 kbps"));
+	      lib_bitrate_box->insertItem(tr("80 kbps"));
+	      lib_bitrate_box->insertItem(tr("96 kbps"));
+	      lib_bitrate_box->insertItem(tr("112 kbps"));
+	      lib_bitrate_box->insertItem(tr("128 kbps"));
+	      lib_bitrate_box->insertItem(tr("160 kbps"));
+	      lib_bitrate_box->insertItem(tr("192 kbps"));
+	      lib_bitrate_box->insertItem(tr("224 kbps"));
+	      lib_bitrate_box->insertItem(tr("256 kbps"));
+	      lib_bitrate_box->insertItem(tr("320 kbps"));
+	      lib_bitrate_box->insertItem(tr("VBR"));
+	      switch(bitrate) {
+		  case 0:
+		    lib_bitrate_box->setCurrentItem(14);
+		    lib_quality_spin->setEnabled(true);
+		    lib_quality_label->setEnabled(true);
+		    lib_quality_spin->setRange(0,9);
+		    lib_quality_spin->setValue(qual);
+		    break;
+		    
+		  case 32000:
+		    lib_bitrate_box->setCurrentItem(0);
+		    lib_quality_spin->setDisabled(true);
+		    lib_quality_label->setDisabled(true);
+		    break;
+		    
+		  case 40000:
+		    lib_bitrate_box->setCurrentItem(1);
+		    lib_quality_spin->setDisabled(true);
+		    lib_quality_label->setDisabled(true);
+		    break;
+		    
+		  case 48000:
+		    lib_bitrate_box->setCurrentItem(2);
+		    lib_quality_spin->setDisabled(true);
+		    lib_quality_label->setDisabled(true);
+		    break;
+		    
+		  case 56000:
+		    lib_bitrate_box->setCurrentItem(3);
+		    lib_quality_spin->setDisabled(true);
+		    lib_quality_label->setDisabled(true);
+		    break;
+		    
+		  case 64000:
+		    lib_bitrate_box->setCurrentItem(4);
+		    lib_quality_spin->setDisabled(true);
+		    lib_quality_label->setDisabled(true);
+		    break;
+		    
+		  case 80000:
+		    lib_bitrate_box->setCurrentItem(5);
+		    lib_quality_spin->setDisabled(true);
+		    lib_quality_label->setDisabled(true);
+		    break;
+		    
+		  case 96000:
+		    lib_bitrate_box->setCurrentItem(6);
+		    lib_quality_spin->setDisabled(true);
+		    lib_quality_label->setDisabled(true);
+		    break;
+		    
+		  case 112000:
+		    lib_bitrate_box->setCurrentItem(7);
+		    lib_quality_spin->setDisabled(true);
+		    lib_quality_label->setDisabled(true);
+		    break;
+		    
+		  case 128000:
+		    lib_bitrate_box->setCurrentItem(8);
+		    lib_quality_spin->setDisabled(true);
+		    lib_quality_label->setDisabled(true);
+		    break;
+		    
+		  case 160000:
+		    lib_bitrate_box->setCurrentItem(9);
+		    lib_quality_spin->setDisabled(true);
+		    lib_quality_label->setDisabled(true);
+		    break;
+		    
+		  case 192000:
+		    lib_bitrate_box->setCurrentItem(10);
+		    lib_quality_spin->setDisabled(true);
+		    lib_quality_label->setDisabled(true);
+		    break;
+		    
+		  case 224000:
+		    lib_bitrate_box->setCurrentItem(11);
+		    lib_quality_spin->setDisabled(true);
+		    lib_quality_label->setDisabled(true);
+		    break;
+		    
+		  case 256000:
+		    lib_bitrate_box->setCurrentItem(12);
+		    lib_quality_spin->setDisabled(true);
+		    lib_quality_label->setDisabled(true);
+		    break;
+		    
+		  case 320000:
+		    lib_bitrate_box->setCurrentItem(13);
+		    lib_quality_spin->setDisabled(true);
+		    lib_quality_label->setDisabled(true);
+		    break;
+	      }
 	      break;
 
-	    case 56000:
-	      lib_bitrate_box->setCurrentItem(3);
-	      lib_quality_spin->setDisabled(true);
-	      lib_quality_label->setDisabled(true);
-	      break;
-
-	    case 64000:
-	      lib_bitrate_box->setCurrentItem(4);
-	      lib_quality_spin->setDisabled(true);
-	      lib_quality_label->setDisabled(true);
-	      break;
-
-	    case 80000:
-	      lib_bitrate_box->setCurrentItem(5);
-	      lib_quality_spin->setDisabled(true);
-	      lib_quality_label->setDisabled(true);
-	      break;
-
-	    case 96000:
-	      lib_bitrate_box->setCurrentItem(6);
-	      lib_quality_spin->setDisabled(true);
-	      lib_quality_label->setDisabled(true);
-	      break;
-
-	    case 112000:
-	      lib_bitrate_box->setCurrentItem(7);
-	      lib_quality_spin->setDisabled(true);
-	      lib_quality_label->setDisabled(true);
-	      break;
-
-	    case 128000:
-	      lib_bitrate_box->setCurrentItem(8);
-	      lib_quality_spin->setDisabled(true);
-	      lib_quality_label->setDisabled(true);
-	      break;
-
-	    case 160000:
-	      lib_bitrate_box->setCurrentItem(9);
-	      lib_quality_spin->setDisabled(true);
-	      lib_quality_label->setDisabled(true);
-	      break;
-
-	    case 192000:
-	      lib_bitrate_box->setCurrentItem(10);
-	      lib_quality_spin->setDisabled(true);
-	      lib_quality_label->setDisabled(true);
-	      break;
-
-	    case 224000:
-	      lib_bitrate_box->setCurrentItem(11);
-	      lib_quality_spin->setDisabled(true);
-	      lib_quality_label->setDisabled(true);
-	      break;
-
-	    case 256000:
-	      lib_bitrate_box->setCurrentItem(12);
-	      lib_quality_spin->setDisabled(true);
-	      lib_quality_label->setDisabled(true);
-	      break;
-
-	    case 320000:
-	      lib_bitrate_box->setCurrentItem(13);
-	      lib_quality_spin->setDisabled(true);
-	      lib_quality_label->setDisabled(true);
+	    case 16000:
+	    case 22050:
+	    case 24000:
+	      lib_bitrate_box->insertItem(tr("8 kbps"));
+	      lib_bitrate_box->insertItem(tr("16 kbps"));
+	      lib_bitrate_box->insertItem(tr("24 kbps"));
+	      lib_bitrate_box->insertItem(tr("32 kbps"));
+	      lib_bitrate_box->insertItem(tr("40 kbps"));
+	      lib_bitrate_box->insertItem(tr("48 kbps"));
+	      lib_bitrate_box->insertItem(tr("56 kbps"));
+	      lib_bitrate_box->insertItem(tr("64 kbps"));
+	      lib_bitrate_box->insertItem(tr("80 kbps"));
+	      lib_bitrate_box->insertItem(tr("96 kbps"));
+	      lib_bitrate_box->insertItem(tr("112 kbps"));
+	      lib_bitrate_box->insertItem(tr("128 kbps"));
+	      lib_bitrate_box->insertItem(tr("144 kbps"));
+	      lib_bitrate_box->insertItem(tr("160 kbps"));
+	      lib_bitrate_box->insertItem(tr("VBR"));
+	      switch(bitrate) {
+		  case 0:
+		    lib_bitrate_box->setCurrentItem(14);
+		    lib_quality_spin->setEnabled(true);
+		    lib_quality_label->setEnabled(true);
+		    lib_quality_spin->setRange(0,9);
+		    lib_quality_spin->setValue(qual);
+		    break;
+		    
+		  case 8000:
+		    lib_bitrate_box->setCurrentItem(0);
+		    lib_quality_spin->setDisabled(true);
+		    lib_quality_label->setDisabled(true);
+		    break;
+		    
+		  case 16000:
+		    lib_bitrate_box->setCurrentItem(1);
+		    lib_quality_spin->setDisabled(true);
+		    lib_quality_label->setDisabled(true);
+		    break;
+		    
+		  case 24000:
+		    lib_bitrate_box->setCurrentItem(2);
+		    lib_quality_spin->setDisabled(true);
+		    lib_quality_label->setDisabled(true);
+		    break;
+		    
+		  case 32000:
+		    lib_bitrate_box->setCurrentItem(3);
+		    lib_quality_spin->setDisabled(true);
+		    lib_quality_label->setDisabled(true);
+		    break;
+		    
+		  case 40000:
+		    lib_bitrate_box->setCurrentItem(4);
+		    lib_quality_spin->setDisabled(true);
+		    lib_quality_label->setDisabled(true);
+		    break;
+		    
+		  case 48000:
+		    lib_bitrate_box->setCurrentItem(5);
+		    lib_quality_spin->setDisabled(true);
+		    lib_quality_label->setDisabled(true);
+		    break;
+		    
+		  case 56000:
+		    lib_bitrate_box->setCurrentItem(6);
+		    lib_quality_spin->setDisabled(true);
+		    lib_quality_label->setDisabled(true);
+		    break;
+		    
+		  case 64000:
+		    lib_bitrate_box->setCurrentItem(7);
+		    lib_quality_spin->setDisabled(true);
+		    lib_quality_label->setDisabled(true);
+		    break;
+		    
+		  case 80000:
+		    lib_bitrate_box->setCurrentItem(8);
+		    lib_quality_spin->setDisabled(true);
+		    lib_quality_label->setDisabled(true);
+		    break;
+		    
+		  case 96000:
+		    lib_bitrate_box->setCurrentItem(9);
+		    lib_quality_spin->setDisabled(true);
+		    lib_quality_label->setDisabled(true);
+		    break;
+		    
+		  case 112000:
+		    lib_bitrate_box->setCurrentItem(10);
+		    lib_quality_spin->setDisabled(true);
+		    lib_quality_label->setDisabled(true);
+		    break;
+		    
+		  case 128000:
+		    lib_bitrate_box->setCurrentItem(11);
+		    lib_quality_spin->setDisabled(true);
+		    lib_quality_label->setDisabled(true);
+		    break;
+		    
+		  case 144000:
+		    lib_bitrate_box->setCurrentItem(12);
+		    lib_quality_spin->setDisabled(true);
+		    lib_quality_label->setDisabled(true);
+		    break;
+		    
+		  case 160000:
+		    lib_bitrate_box->setCurrentItem(13);
+		    lib_quality_spin->setDisabled(true);
+		    lib_quality_label->setDisabled(true);
+		    break;
+	      }
 	      break;
 	}
 	break;
