@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2003-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdplay_deck.cpp,v 1.71 2007/07/15 20:51:31 stgabriel Exp $
+//      $Id: rdplay_deck.cpp,v 1.73 2007/12/29 18:16:10 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -174,16 +174,14 @@ bool RDPlayDeck::setCart(RDLogLine *logline,bool rotate)
   if(logline->segueStartPoint(RDLogLine::AutoPointer)<0) {
     play_point_value[RDPlayDeck::Segue][0]=play_cut->segueStartPoint();
     play_point_value[RDPlayDeck::Segue][1]=play_cut->segueEndPoint();
-    play_point_gain=RD_FADE_DEPTH;
   }
   else {
     play_point_value[RDPlayDeck::Segue][0]=logline->
       segueStartPoint(RDLogLine::AutoPointer);
     play_point_value[RDPlayDeck::Segue][1]=logline->
       segueEndPoint(RDLogLine::AutoPointer);
-    play_point_gain=logline->segueGain();
   }
-  play_overlap=false;
+  play_point_gain=logline->segueGain();
   play_point_value[RDPlayDeck::Hook][0]=play_cut->hookStartPoint();
   play_point_value[RDPlayDeck::Hook][1]=play_cut->hookEndPoint();
   play_point_value[RDPlayDeck::Talk][0]=play_cut->talkStartPoint();
@@ -460,11 +458,14 @@ void RDPlayDeck::stop()
 }
 
 
-void RDPlayDeck::stop(int interval, bool overlap)
+void RDPlayDeck::stop(int interval,int gain)
 {
   int level;
-  play_overlap=overlap;
-
+  
+  if(gain>play_point_gain) {
+    play_point_gain=gain;
+  }
+  
 
   if((play_state!=RDPlayDeck::Playing)&&(play_state!=RDPlayDeck::Stopping)) {
     return;
@@ -492,9 +493,10 @@ void RDPlayDeck::stop(int interval, bool overlap)
       }
     }
     else {
-	    if(play_point_gain!=0  && !play_overlap)
-    play_cae->fadeOutputVolume(play_card,play_stream,play_port,
+      if(play_point_gain!=0) {
+        play_cae->fadeOutputVolume(play_card,play_stream,play_port,
 			       play_point_gain+play_cut_gain+play_duck_level,interval);
+      }
     }
     play_stop_timer->start(interval,true);
     stop_called=true;
@@ -503,24 +505,6 @@ void RDPlayDeck::stop(int interval, bool overlap)
 }
 
 
-void RDPlayDeck::stop(int interval,int gain)
-{
-  if((play_state!=RDPlayDeck::Playing)&&(play_state!=RDPlayDeck::Stopping)) {
-    return;
-  }
-  if((interval<=0)||pause_called) {
-    stop();
-  }
-  else {
-    if(gain!=0){
-    play_cae->fadeOutputVolume(play_card,play_stream,play_port,
-	  		           gain+play_cut_gain+play_duck_level,interval);
-    }
-  }
-    play_stop_timer->start(interval,true);
-    stop_called=true;
-    play_state=RDPlayDeck::Stopping;
-}
 
 
 void RDPlayDeck::duckDown(int interval)
@@ -665,7 +649,7 @@ void RDPlayDeck::duckTimerData()
     play_ducked=0;
   }
   else { //duck down
-	  if(play_point_gain!=0 && !play_overlap) {
+	  if(play_point_gain!=0) {
       play_cae->fadeOutputVolume(play_card,play_stream,play_port,
 	  		       play_point_gain+play_cut_gain+play_duck_level,
                                play_segue_interval-play_duck_down);
