@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdstation.cpp,v 1.16 2007/06/12 20:26:34 fredg Exp $
+//      $Id: rdstation.cpp,v 1.21 2007/12/12 19:20:38 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,11 +20,10 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <rconf.h>
-
+#include <rdconf.h>
 #include <rdstation.h>
 #include <rd.h>
-
+#include <rddb.h> 
 
 //
 // Global Classes
@@ -32,7 +31,7 @@
 RDStation::RDStation(QString name,bool create)
 {
   QString sql;
-
+  time_offset_valid = false;
   station_name=name;
 }
 
@@ -45,7 +44,7 @@ RDStation::~RDStation()
 
 bool RDStation::exists() const
 {
-  return RDoesRowExist("STATIONS","NAME",station_name);
+  return RDDoesRowExist("STATIONS","NAME",station_name);
 }
 
 
@@ -57,7 +56,7 @@ QString RDStation::name() const
 
 QString RDStation::description() const
 {
-  return RGetSqlValue("STATIONS","NAME",station_name,"DESCRIPTION").toString();
+  return RDGetSqlValue("STATIONS","NAME",station_name,"DESCRIPTION").toString();
 }
 
 
@@ -69,7 +68,7 @@ void RDStation::setDescription(QString desc) const
 
 QString RDStation::userName() const
 {
-  return RGetSqlValue("STATIONS","NAME",station_name,"USER_NAME").toString();
+  return RDGetSqlValue("STATIONS","NAME",station_name,"USER_NAME").toString();
 }
 
 
@@ -81,7 +80,7 @@ void RDStation::setUserName(QString name) const
 
 QString RDStation::defaultName() const
 {
-  return RGetSqlValue("STATIONS","NAME",station_name,"DEFAULT_NAME").
+  return RDGetSqlValue("STATIONS","NAME",station_name,"DEFAULT_NAME").
     toString();
 }
 
@@ -95,7 +94,7 @@ void RDStation::setDefaultName(QString name) const
 QHostAddress RDStation::address() const
 {
   QHostAddress addr;
-  addr.setAddress(RGetSqlValue("STATIONS","NAME",station_name,"IPV4_ADDRESS").
+  addr.setAddress(RDGetSqlValue("STATIONS","NAME",station_name,"IPV4_ADDRESS").
 		  toString());
   return addr;
 }
@@ -107,21 +106,26 @@ void RDStation::setAddress(QHostAddress addr) const
 }
 
 
-int RDStation::timeOffset() const
+int RDStation::timeOffset()
 {
-  return RGetSqlValue("STATIONS","NAME",station_name,"TIME_OFFSET").toInt();
+  if (!time_offset_valid){
+    time_offset = RDGetSqlValue("STATIONS","NAME",station_name,"TIME_OFFSET").toInt();
+    time_offset_valid = true;
+  }
+  return time_offset;
 }
 
 
-void RDStation::setTimeOffset(int msecs) const
+void RDStation::setTimeOffset(int msecs)
 {
   SetRow("TIME_OFFSET",msecs);
+  time_offset = msecs;
 }
 
 
 QString RDStation::backupPath() const
 {
-  return RGetSqlValue("STATIONS","NAME",station_name,"BACKUP_DIR").toString();
+  return RDGetSqlValue("STATIONS","NAME",station_name,"BACKUP_DIR").toString();
 }
 
 
@@ -133,7 +137,7 @@ void RDStation::setBackupPath(QString path) const
 
 int RDStation::backupLife() const
 {
-  return RGetSqlValue("STATIONS","NAME",station_name,"BACKUP_LIFE").toInt();
+  return RDGetSqlValue("STATIONS","NAME",station_name,"BACKUP_LIFE").toInt();
 }
 
 
@@ -145,7 +149,7 @@ void RDStation::setBackupLife(int days) const
 
 unsigned RDStation::heartbeatCart() const
 {
-  return RGetSqlValue("STATIONS","NAME",station_name,"HEARTBEAT_CART").
+  return RDGetSqlValue("STATIONS","NAME",station_name,"HEARTBEAT_CART").
     toUInt();
 }
 
@@ -158,7 +162,7 @@ void RDStation::setHeartbeatCart(unsigned cartnum) const
 
 unsigned RDStation::heartbeatInterval() const
 {
-  return RGetSqlValue("STATIONS","NAME",station_name,"HEARTBEAT_INTERVAL").
+  return RDGetSqlValue("STATIONS","NAME",station_name,"HEARTBEAT_INTERVAL").
     toUInt();
 }
 
@@ -171,7 +175,7 @@ void RDStation::setHeartbeatInterval(unsigned interval) const
 
 unsigned RDStation::startupCart() const
 {
-  return RGetSqlValue("STATIONS","NAME",station_name,"STARTUP_CART").
+  return RDGetSqlValue("STATIONS","NAME",station_name,"STARTUP_CART").
     toUInt();
 }
 
@@ -182,9 +186,35 @@ void RDStation::setStartupCart(unsigned cartnum) const
 }
 
 
+QString RDStation::editorPath() const
+{
+  return RDGetSqlValue("STATIONS","NAME",station_name,"EDITOR_PATH").
+    toString();
+}
+
+
+void RDStation::setEditorPath(const QString &cmd)
+{
+  SetRow("EDITOR_PATH",cmd);
+}
+
+
+RDStation::FilterMode RDStation::filterMode() const
+{
+  return (RDStation::FilterMode)RDGetSqlValue("STATIONS","NAME",station_name,
+					      "FILTER_MODE").toInt();
+}
+
+
+void RDStation::setFilterMode(RDStation::FilterMode mode) const
+{
+  SetRow("FILTER_MODE",(int)mode);
+}
+
+
 bool RDStation::scanned() const
 {
-  return RBool(RGetSqlValue("STATIONS","NAME",station_name,"STATION_SCANNED").
+  return RDBool(RDGetSqlValue("STATIONS","NAME",station_name,"STATION_SCANNED").
 	       toString());
 }
 
@@ -199,27 +229,27 @@ bool RDStation::haveCapability(Capability cap) const
 {
   switch(cap) {
       case RDStation::HaveOggenc:
-	return RBool(RGetSqlValue("STATIONS","NAME",station_name,
+	return RDBool(RDGetSqlValue("STATIONS","NAME",station_name,
 				  "HAVE_OGGENC").toString());
 	break;
 
       case RDStation::HaveOgg123:
-	return RBool(RGetSqlValue("STATIONS","NAME",station_name,
+	return RDBool(RDGetSqlValue("STATIONS","NAME",station_name,
 				  "HAVE_OGG123").toString());
 	break;
 
       case RDStation::HaveFlac:
-	return RBool(RGetSqlValue("STATIONS","NAME",station_name,
+	return RDBool(RDGetSqlValue("STATIONS","NAME",station_name,
 				  "HAVE_FLAC").toString());
 	break;
 
       case RDStation::HaveLame:
-	return RBool(RGetSqlValue("STATIONS","NAME",station_name,
+	return RDBool(RDGetSqlValue("STATIONS","NAME",station_name,
 				  "HAVE_LAME").toString());
 	break;
 
       case RDStation::HaveMpg321:
-	return RBool(RGetSqlValue("STATIONS","NAME",station_name,
+	return RDBool(RDGetSqlValue("STATIONS","NAME",station_name,
 				  "HAVE_MPG321").toString());
 	break;
   }
@@ -262,7 +292,7 @@ int RDStation::cards() const
                                  CARD5_DRIVER,CARD6_DRIVER,CARD7_DRIVER\
                                  from STATIONS where NAME=\"%s\"",
 				(const char *)station_name);
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   if(q->first()) {
     for(int i=0;i<RD_MAX_CARDS;i++) {
       if((RDStation::AudioDriver)q->value(i).toInt()!=RDStation::None) {
@@ -283,7 +313,7 @@ int RDStation::cards() const
 RDStation::AudioDriver RDStation::cardDriver(int cardnum) const
 {
   return (RDStation::AudioDriver)
-    RGetSqlValue("STATIONS","NAME",station_name,
+    RDGetSqlValue("STATIONS","NAME",station_name,
 		 QString().sprintf("CARD%d_DRIVER",cardnum)).
     toInt();
 }
@@ -302,15 +332,15 @@ QString RDStation::driverVersion(AudioDriver driver) const
 	return QString();
 
       case RDStation::Hpi:
-	return RGetSqlValue("STATIONS","NAME",station_name,"HPI_VERSION").
+	return RDGetSqlValue("STATIONS","NAME",station_name,"HPI_VERSION").
 	  toString();
 
       case RDStation::Jack:
-	return RGetSqlValue("STATIONS","NAME",station_name,"JACK_VERSION").
+	return RDGetSqlValue("STATIONS","NAME",station_name,"JACK_VERSION").
 	  toString();
 
       case RDStation::Alsa:
-	return RGetSqlValue("STATIONS","NAME",station_name,"ALSA_VERSION").
+	return RDGetSqlValue("STATIONS","NAME",station_name,"ALSA_VERSION").
 	  toString();
   }
   return QString();
@@ -340,7 +370,7 @@ void RDStation::setDriverVersion(AudioDriver driver,QString ver) const
 
 QString RDStation::cardName(int cardnum) const
 {
-  return RGetSqlValue("STATIONS","NAME",station_name,
+  return RDGetSqlValue("STATIONS","NAME",station_name,
 		      QString().sprintf("CARD%d_NAME",cardnum)).toString();
 }
 
@@ -353,7 +383,7 @@ void RDStation::setCardName(int cardnum,QString name) const
 
 int RDStation::cardInputs(int cardnum) const
 {
-  return RGetSqlValue("STATIONS","NAME",station_name,
+  return RDGetSqlValue("STATIONS","NAME",station_name,
 		      QString().sprintf("CARD%d_INPUTS",cardnum)).toInt();
 }
 
@@ -366,7 +396,7 @@ void RDStation::setCardInputs(int cardnum,int inputs) const
 
 int RDStation::cardOutputs(int cardnum) const
 {
-  return RGetSqlValue("STATIONS","NAME",station_name,
+  return RDGetSqlValue("STATIONS","NAME",station_name,
 		      QString().sprintf("CARD%d_OUTPUTS",cardnum)).toInt();
 }
 
@@ -379,55 +409,55 @@ void RDStation::setCardOutputs(int cardnum,int outputs) const
 
 void RDStation::SetRow(QString param,QString value) const
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   sql=QString().sprintf("UPDATE STATIONS SET %s=\"%s\" WHERE NAME=\"%s\"",
 			(const char *)param,
 			(const char *)value,
 			(const char *)station_name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 }
 
 
 void RDStation::SetRow(QString param,int value) const
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   sql=QString().sprintf("UPDATE STATIONS SET %s=%d WHERE NAME=\"%s\"",
 			(const char *)param,
 			value,
 			(const char *)station_name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 }
 
 
 void RDStation::SetRow(QString param,unsigned value) const
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   sql=QString().sprintf("UPDATE STATIONS SET %s=%u WHERE NAME=\"%s\"",
 			(const char *)param,
 			value,
 			(const char *)station_name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 }
 
 
 void RDStation::SetRow(QString param,bool value) const
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   sql=QString().sprintf("UPDATE STATIONS SET %s=\"%s\" WHERE NAME=\"%s\"",
 			(const char *)param,
-			(const char *)RYesNo(value),
+			(const char *)RDYesNo(value),
 			(const char *)station_name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 }
