@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdsvc.h,v 1.21 2007/02/14 21:48:41 fredg Exp $
+//      $Id: rdsvc.h,v 1.22 2007/08/31 17:41:12 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -52,12 +52,12 @@ class RDSvc : public QObject
   void setChainto(bool state) const;
   QString breakString() const;
   void setBreakString(const QString &str);
-  QString trackString() const;
-  void setTrackString(const QString &str);
-  QString labelCart() const;
-  void setLabelCart(const QString &str);
-  QString trackCart() const;
-  void setTrackCart(const QString &str);
+  QString trackString(ImportSource src) const;
+  void setTrackString(ImportSource src,const QString &str);
+  QString labelCart(ImportSource src) const;
+  void setLabelCart(ImportSource src,const QString &str);
+  QString trackCart(ImportSource src) const;
+  void setTrackCart(ImportSource src,const QString &str);
   QString importPath(ImportSource src,ImportOs os) const;
   void setImportPath(ImportSource src,ImportOs os,const QString &path) const;
   int importOffset(ImportSource src,ImportField field) const;
@@ -82,9 +82,12 @@ class RDSvc : public QObject
   void generationProgress(int step);
 
  private:
+  QString SourceString(ImportSource src) const;
+  QString OsString(ImportOs os) const;
+  QString FieldString(ImportField field) const;
   void SetRow(const QString &param,QString value) const;
   void SetRow(const QString &param,int value) const;
-  void GetParserStrings(QString *break_str,QString *track_str,
+  void GetParserStrings(ImportSource src,QString *break_str,QString *track_str,
 			QString *label_cart,QString *track_cart);
   bool CheckId(std::vector<int> *v,int value);
   QString svc_name;
