@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_rdairplay.cpp,v 1.38 2007/07/10 16:02:22 fredg Exp $
+//      $Id: edit_rdairplay.cpp,v 1.43 2007/12/05 20:17:32 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -31,13 +31,10 @@
 #include <qmessagebox.h>
 #include <qcheckbox.h>
 #include <qbuttongroup.h>
-#include <qsqldatabase.h>
 #include <qpainter.h>
 
-#include <rconf.h>
-#include <math.h>
-
 #include <rd.h>
+#include <rddb.h>
 #include <rdtextvalidator.h>
 #include <rdlist_logs.h>
 
@@ -50,7 +47,7 @@ EditRDAirPlay::EditRDAirPlay(RDStation *station,unsigned instance,
   : QDialog(parent,name,true)
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
 
   air_exitpasswd_changed=false;
   air_logmachine=0;
@@ -303,15 +300,6 @@ EditRDAirPlay::EditRDAirPlay(RDStation *station,unsigned instance,
   label->setGeometry(510,343,65,19);
   label->setAlignment(AlignVCenter|AlignRight);
 
-  //
-  // Now & Next Button
-  //
-  QPushButton *button=new QPushButton(this,"nownext_button");
-  button->setGeometry(815,562,180,50);
-  button->setFont(small_font);
-  button->setText(tr("Configure Now && Next\nParameters"));
-  connect(button,SIGNAL(clicked()),this,SLOT(nownextData()));
-  
   //
   // Main Log Play Section
   //
@@ -385,6 +373,7 @@ EditRDAirPlay::EditRDAirPlay(RDStation *station,unsigned instance,
   air_default_transtype_box->insertItem(tr("Play"));
   air_default_transtype_box->insertItem(tr("Segue"));
   air_default_transtype_box->insertItem(tr("Stop"));
+  air_default_transtype_box->insertItem(tr("Overlap"));
 
   //
   // Default Service
@@ -482,47 +471,47 @@ EditRDAirPlay::EditRDAirPlay(RDStation *station,unsigned instance,
   // Check Timesync
   //
   air_timesync_box=new QCheckBox(this,"air_timesync_box");
-  air_timesync_box->setGeometry(810,381,15,15);
+  air_timesync_box->setGeometry(810,378,15,15);
   air_timesync_label=new QLabel(air_timesync_box,tr("Check TimeSync"),
 			     this,"air_timesync_label");
-  air_timesync_label->setGeometry(830,381,100,15);
+  air_timesync_label->setGeometry(830,378,100,15);
   air_timesync_label->setAlignment(AlignLeft|AlignVCenter);
 
   //
   // Show Log Buttons
   //
   air_auxlog_box[0]=new QCheckBox(this,"air_auxlog1_box");
-  air_auxlog_box[0]->setGeometry(810,403,15,15);
+  air_auxlog_box[0]->setGeometry(810,400,15,15);
   label=new QLabel(air_auxlog_box[0],tr("Show Auxlog 1 Button"),
 		   this,"air_auxlog_label");
-  label->setGeometry(830,403,150,15);
+  label->setGeometry(830,400,150,15);
   label->setAlignment(AlignLeft|AlignVCenter);
 
   air_auxlog_box[1]=new QCheckBox(this,"air_auxlog2_box");
-  air_auxlog_box[1]->setGeometry(810,425,15,15);
+  air_auxlog_box[1]->setGeometry(810,423,15,15);
   label=new QLabel(air_auxlog_box[1],tr("Show Auxlog 2 Button"),
 		   this,"air_auxlog_label");
-  label->setGeometry(830,425,150,15);
+  label->setGeometry(830,423,150,15);
   label->setAlignment(AlignLeft|AlignVCenter);
 
   //
   // Clear Cart Filter
   //
   air_clearfilter_box=new QCheckBox(this,"air_clearfilter_box");
-  air_clearfilter_box->setGeometry(810,447,15,15);
+  air_clearfilter_box->setGeometry(810,444,15,15);
   label=new QLabel(air_clearfilter_box,tr("Clear Cart Search Filter"),
 		   this,"air_clearfilter_label");
-  label->setGeometry(830,447,150,15);
+  label->setGeometry(830,444,150,15);
   label->setAlignment(AlignLeft|AlignVCenter);
 
   //
   // Pause Enable Checkbox
   //
   air_pause_box=new QCheckBox(this,"air_pause_box");
-  air_pause_box->setGeometry(810,469,15,15);
+  air_pause_box->setGeometry(810,466,15,15);
   label=new QLabel(air_pause_box,tr("Enable Paused Events"),
 		   this,"air_pause_label");
-  label->setGeometry(830,469,150,15);
+  label->setGeometry(830,466,150,15);
   label->setAlignment(AlignLeft|AlignVCenter);
 
   //
@@ -530,11 +519,20 @@ EditRDAirPlay::EditRDAirPlay(RDStation *station,unsigned instance,
   //
   air_bar_group=new QButtonGroup(1,Qt::Vertical,tr("Space Bar Action"),
 				 this,"air_bar_group");
-  air_bar_group->setGeometry(805,491,sizeHint().width()-815,55);
+  air_bar_group->setGeometry(805,488,sizeHint().width()-815,55);
   QRadioButton *rbutton=
     new QRadioButton(tr("None"),air_bar_group,"none_button");
   rbutton=new QRadioButton(tr("Start Next"),air_bar_group,"start_next_button");
 
+  //
+  // Now & Next Button
+  //
+  QPushButton *button=new QPushButton(this,"nownext_button");
+  button->setGeometry(815,559,180,50);
+  button->setFont(small_font);
+  button->setText(tr("Configure Now && Next\nParameters"));
+  connect(button,SIGNAL(clicked()),this,SLOT(nownextData()));
+  
   //
   // Start/Stop Section
   //
@@ -635,6 +633,21 @@ EditRDAirPlay::EditRDAirPlay(RDStation *station,unsigned instance,
   //
   // Populate Fields
   //
+  if(station->scanned()) {
+    for(int i=0;i<10;i++) {
+      air_card_sel[i]->setMaxCards(station->cards());
+      for(int j=0;j<air_card_sel[i]->maxCards();j++) {
+	air_card_sel[i]->setMaxPorts(j,station->cardOutputs(j));
+      }
+    }
+  }
+  else {
+    QMessageBox::information(this,tr("No Audio Configuration Data"),
+			    tr("Channel assignments will not be available for this host, as audio resource data\nhas not yet been generated.  Please start the Rivendell daemons on this host\n(by executing, as user 'root',  the command \"/etc/init.d/rivendell start\")\nin order to populate the audio resources database."));
+    for(int i=0;i<6;i++) {
+      air_card_sel[i]->setDisabled(true);
+    }
+  }
   for(int i=0;i<10;i++) {
     air_card_sel[i]->setCard(air_conf->card(i));
     air_card_sel[i]->setPort(air_conf->port(i));
@@ -650,7 +663,7 @@ EditRDAirPlay::EditRDAirPlay(RDStation *station,unsigned instance,
   sql=QString().sprintf("select SERVICE_NAME from SERVICE_PERMS \
                          where STATION_NAME=\"%s\"",
 			(const char *)air_conf->station());
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     air_defaultsvc_box->insertItem(q->value(0).toString());
     if(defaultsvc==q->value(0).toString()) {
@@ -683,21 +696,6 @@ EditRDAirPlay::EditRDAirPlay(RDStation *station,unsigned instance,
   air_startlog_edit->setText(air_startlog[air_logmachine]);
   air_autorestart_box->setChecked(air_autorestart[air_logmachine]);
   startModeChangedData(air_startmode[air_logmachine]);
-  if(station->scanned()) {
-    for(int i=0;i<10;i++) {
-      air_card_sel[i]->setMaxCards(station->cards());
-      for(int j=0;j<air_card_sel[i]->maxCards();j++) {
-	air_card_sel[i]->setMaxPorts(j,station->cardOutputs(j));
-      }
-    }
-  }
-  else {
-    QMessageBox::information(this,tr("No Audio Configuration Data"),
-			    tr("Channel assignments will not be available for this host, as audio resource data\nhas not yet been generated.  Please start the Rivendell daemons on this host\n(by executing, as user 'root',  the command \"/etc/init.d/rivendell start\")\nin order to populate the audio resources database."));
-    for(int i=0;i<6;i++) {
-      air_card_sel[i]->setDisabled(true);
-    }
-  }
 }
 
 
