@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_rdpanel.cpp,v 1.3 2007/09/14 14:06:26 fredg Exp $
+//      $Id: edit_rdpanel.cpp,v 1.6 2007/12/05 20:17:32 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -31,9 +31,9 @@
 #include <qmessagebox.h>
 #include <qcheckbox.h>
 #include <qbuttongroup.h>
-#include <qsqldatabase.h>
 #include <qpainter.h>
 
+#include <rddb.h>
 #include <rd.h>
 #include <rdtextvalidator.h>
 #include <rdlist_logs.h>
@@ -47,7 +47,7 @@ EditRDPanel::EditRDPanel(RDStation *station,unsigned instance,
   : QDialog(parent,name,true)
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
 
   //
   // Fix the Window Size
@@ -193,6 +193,27 @@ EditRDPanel::EditRDPanel(RDStation *station,unsigned instance,
   label->setGeometry(135,343,65,19);
   label->setAlignment(AlignVCenter|AlignRight);
 
+  //
+  // Sound Panel Cue Play Output
+  //
+  label=new QLabel(tr("SoundPanel Cue Output"),this,"globals_label");
+  label->setFont(small_font);
+  label->setGeometry(20,372,300,16);
+  air_card_sel[5]=new RDCardSelector(this,"air_card5_sel");
+  air_card_sel[5]->setGeometry(15,390,120,117);
+  air_start_rml_edit[5]=new QLineEdit(this);
+  air_start_rml_edit[5]->setGeometry(205,390,160,19);
+  air_start_rml_edit[5]->setValidator(validator);
+  label=new QLabel(air_start_rml_edit[5],tr("Start RML:"),this);
+  label->setGeometry(135,390,65,19);
+  label->setAlignment(AlignVCenter|AlignRight);
+  air_stop_rml_edit[5]=new QLineEdit(this);
+  air_stop_rml_edit[5]->setGeometry(205,411,160,19);
+  air_stop_rml_edit[5]->setValidator(validator);
+  label=new QLabel(air_start_rml_edit[5],tr("Stop RML:"),this);
+  label->setGeometry(135,411,65,19);
+  label->setAlignment(AlignVCenter|AlignRight);
+
   //
   // Sound Panel Section
   //
@@ -297,6 +318,21 @@ EditRDPanel::EditRDPanel(RDStation *station,unsigned instance,
   //
   // Populate Fields
   //
+  if(station->scanned()) {
+    for(int i=0;i<6;i++) {
+      air_card_sel[i]->setMaxCards(station->cards());
+      for(int j=0;j<air_card_sel[i]->maxCards();j++) {
+	air_card_sel[i]->setMaxPorts(j,station->cardOutputs(j));
+      }
+    }
+  }
+  else {
+    QMessageBox::information(this,tr("No Audio Configuration Data"),
+			    tr("Channel assignments will not be available for this host, as audio resource data\nhas not yet been generated.  Please start the Rivendell daemons on this host\n(by executing, as user 'root',  the command \"/etc/init.d/rivendell start\")\nin order to populate the audio resources database."));
+    for(int i=0;i<6;i++) {
+      air_card_sel[i]->setDisabled(true);
+    }
+  }
   air_card_sel[0]->setCard(air_conf->card(2));
   air_card_sel[0]->setPort(air_conf->port(2));
 
@@ -312,12 +348,15 @@ EditRDPanel::EditRDPanel(RDStation *station,unsigned instance,
   air_card_sel[4]->setCard(air_conf->card(9));
   air_card_sel[4]->setPort(air_conf->port(9));
 
+  air_card_sel[5]->setCard(air_conf->card(3));
+  air_card_sel[5]->setPort(air_conf->port(3));
+
   air_defaultsvc_box->insertItem(tr("[none]"));
   QString defaultsvc=air_conf->defaultSvc();
   sql=QString().sprintf("select SERVICE_NAME from SERVICE_PERMS \
                          where STATION_NAME=\"%s\"",
 			(const char *)air_conf->station());
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     air_defaultsvc_box->insertItem(q->value(0).toString());
     if(defaultsvc==q->value(0).toString()) {
@@ -345,21 +384,9 @@ EditRDPanel::EditRDPanel(RDStation *station,unsigned instance,
 
   air_start_rml_edit[4]->setText(air_conf->startRml(9));
   air_stop_rml_edit[4]->setText(air_conf->stopRml(9));
-  if(station->scanned()) {
-    for(int i=0;i<5;i++) {
-      air_card_sel[i]->setMaxCards(station->cards());
-      for(int j=0;j<air_card_sel[i]->maxCards();j++) {
-	air_card_sel[i]->setMaxPorts(j,station->cardOutputs(j));
-      }
-    }
-  }
-  else {
-    QMessageBox::information(this,tr("No Audio Configuration Data"),
-			    tr("Channel assignments will not be available for this host, as audio resource data\nhas not yet been generated.  Please start the Rivendell daemons on this host\n(by executing, as user 'root',  the command \"/etc/init.d/rivendell start\")\nin order to populate the audio resources database."));
-    for(int i=0;i<6;i++) {
-      air_card_sel[i]->setDisabled(true);
-    }
-  }
+
+  air_start_rml_edit[5]->setText(air_conf->startRml(3));
+  air_stop_rml_edit[5]->setText(air_conf->stopRml(3));
 }
 
 
@@ -370,7 +397,7 @@ EditRDPanel::~EditRDPanel()
 
 QSize EditRDPanel::sizeHint() const
 {
-  return QSize(630,379);
+  return QSize(630,447);
 } 
 
 
@@ -406,6 +433,11 @@ void EditRDPanel::okData()
   air_conf->setStopRml(9,air_stop_rml_edit[4]->text());
   air_conf->setCard(9,air_card_sel[4]->card());
   air_conf->setPort(9,air_card_sel[4]->port());
+
+  air_conf->setStartRml(3,air_start_rml_edit[5]->text());
+  air_conf->setStopRml(3,air_stop_rml_edit[5]->text());
+  air_conf->setCard(3,air_card_sel[5]->card());
+  air_conf->setPort(3,air_card_sel[5]->port());
   if(air_defaultsvc_box->currentItem()==0) {
     air_conf->setDefaultSvc("");
   }
