@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: list_dropboxes.cpp,v 1.2 2007/09/14 14:06:27 fredg Exp $
+//      $Id: list_dropboxes.cpp,v 1.4 2007/10/05 13:50:31 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -30,8 +30,8 @@
 #include <qevent.h>
 #include <qmessagebox.h>
 #include <qbuttongroup.h>
-#include <qsqldatabase.h>
 
+#include <rddb.h>
 #include <list_dropboxes.h>
 #include <edit_dropbox.h>
 
@@ -152,7 +152,7 @@ void ListDropboxes::addData()
   EditDropbox *edit_dropbox=new EditDropbox(id,this,"edit_dropbox");
   if(edit_dropbox->exec()<0) {
     QString sql=QString().sprintf("delete from DROPBOXES where ID=%d",id);
-    QSqlQuery *q=new QSqlQuery(sql);
+    RDSqlQuery *q=new RDSqlQuery(sql);
     delete q;
     delete edit_dropbox;
     return;
@@ -188,7 +188,7 @@ void ListDropboxes::deleteData()
 
   QString 
     sql=QString().sprintf("delete from DROPBOXES where ID=%d",item->id());
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   delete q;
   delete item;
 }
@@ -221,7 +221,7 @@ void ListDropboxes::resizeEvent(QResizeEvent *e)
 void ListDropboxes::RefreshList()
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   RDListViewItem *item;
 
   list_dropboxes_view->clear();
@@ -235,7 +235,7 @@ void ListDropboxes::RefreshList()
                          DROPBOXES.GROUP_NAME=GROUPS.NAME \
                          where DROPBOXES.STATION_NAME=\"%s\"",
 			(const char *)list_stationname);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while (q->next()) {
     item=new RDListViewItem(list_dropboxes_view);
     WriteItem(item,q);
@@ -247,7 +247,7 @@ void ListDropboxes::RefreshList()
 void ListDropboxes::RefreshItem(RDListViewItem *item)
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
 
   sql=QString().sprintf("select DROPBOXES.ID,DROPBOXES.GROUP_NAME,\
                          DROPBOXES.PATH,DROPBOXES.NORMALIZATION_LEVEL,\
@@ -258,7 +258,7 @@ void ListDropboxes::RefreshItem(RDListViewItem *item)
                          from DROPBOXES left join GROUPS on \
                          DROPBOXES.GROUP_NAME=GROUPS.NAME \
                          where DROPBOXES.ID=%d",item->id());
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   if(q->next()) {
     WriteItem(item,q);
   }
@@ -266,7 +266,7 @@ void ListDropboxes::RefreshItem(RDListViewItem *item)
 }
 
 
-void ListDropboxes::WriteItem(RDListViewItem *item,QSqlQuery *q)
+void ListDropboxes::WriteItem(RDListViewItem *item,RDSqlQuery *q)
 {
   item->setId(q->value(0).toInt());
   item->setText(0,q->value(1).toString());
