@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: list_matrices.cpp,v 1.21 2007/09/14 14:06:27 fredg Exp $
+//      $Id: list_matrices.cpp,v 1.23 2007/10/23 18:21:57 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -30,10 +30,9 @@
 #include <qevent.h>
 #include <qmessagebox.h>
 #include <qbuttongroup.h>
-#include <qsqldatabase.h>
 
 #include <rdstation.h>
-
+#include <rddb.h>
 #include <globals.h>
 #include <list_matrices.h>
 #include <edit_matrix.h>
@@ -256,19 +255,19 @@ void ListMatrices::DeleteMatrix(int matrix)
                                STATION_NAME=\"%s\" && MATRIX=%d",
 				(const char *)list_station,
 				matrix);
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   delete q;
   sql=QString().sprintf("delete from INPUTS where \
                          STATION_NAME=\"%s\" && MATRIX=%d",
 			(const char *)list_station,
 			matrix);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
   sql=QString().sprintf("delete from OUTPUTS where \
                          STATION_NAME=\"%s\" && MATRIX=%d",
 			(const char *)list_station,
 			matrix);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 }
 
@@ -281,7 +280,7 @@ void ListMatrices::RefreshList()
   QString sql=QString().sprintf("select MATRIX,NAME,TYPE from MATRICES \
                                  where STATION_NAME=\"%s\" order by MATRIX",
 				(const char *)list_station);
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   while(q->next()) {
     l=new QListViewItem(list_view);
     l->setText(0,q->value(0).toString());
@@ -376,6 +375,9 @@ QString ListMatrices::TypeString(RDMatrix::Type type)
       case RDMatrix::BtSs42:
 	return QString(tr("BroadcastTools SS4.2"));
 
+      case RDMatrix::LiveWire:
+	return QString(tr("Axia LiveWire"));
+
       default:
 	return QString(tr("Unknown"));
   }
