@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: opendb.cpp,v 1.28 2007/09/14 14:06:27 fredg Exp $
+//      $Id: opendb.cpp,v 1.30 2007/11/07 13:26:55 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -22,12 +22,12 @@
 
 #include <stdlib.h>
 #include <unistd.h>
-#include <qsqldatabase.h>
 #include <qsqldriver.h>
 #include <qmessagebox.h>
 #include <opendb.h>
 #include <createdb.h>
 #include <rd.h>
+#include <rddb.h>
 #include <dbversion.h>
 #include <rdcheck_version.h>
 #include <rdcheck_daemons.h>
@@ -152,7 +152,7 @@ bool OpenDb(QString dbname,QString login,QString pwd,QString host,
   QString admin_name;
   QString admin_pwd;
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString msg;
   MySqlLogin *mysql_login;
   QString str;
@@ -202,7 +202,7 @@ and we will try to get this straightened out.");
       }
       else {              // Create a new Rivendell Database
 	sql=QString().sprintf("create database %s",(const char *)dbname);
-	q=new QSqlQuery(sql);
+	q=new RDSqlQuery(sql);
 	if(!q->isActive()) {   // Can't create DB.
 	  delete q;
 	  QMessageBox::warning(NULL,QT_TR_NOOP("Can't Create DB"),
@@ -222,17 +222,17 @@ and we will try to get this straightened out.");
 	sql=QString().sprintf("insert into user set Host=\"%s\",\
             User=\"%s\",Password=PASSWORD(\"%s\")",
 			      (const char *)host, (const char *)login,(const char *)pwd);
-	q=new QSqlQuery(sql);
+	q=new RDSqlQuery(sql);
 	delete q;
 	sql=QString().
 	  sprintf("insert into db set Host=\"%s\",Db=\"%s\",\
             User=\"%s\",Select_priv=\"Y\",Insert_priv=\"Y\",Update_priv=\"Y\",\
             Delete_priv=\"Y\",Create_priv=\"Y\",Drop_priv=\"Y\",\
-            Index_priv=\"Y\",Alter_priv=\"Y\"",
-		  (const char *)host, (const char *)dbname,(const char *)login);
-	q=new QSqlQuery(sql);
+            Index_priv=\"Y\",Alter_priv=\"Y\",Lock_tables_priv=\"Y\"",
+		 (const char *)host, (const char *)dbname,(const char *)login);
+	q=new RDSqlQuery(sql);
 	delete q;
-	q=new QSqlQuery("flush privileges");
+	q=new RDSqlQuery("flush privileges");
 	delete q;
 	db->close();   // Relinquish admin perms
 	db->setDatabaseName(dbname);
@@ -301,9 +301,9 @@ with administrative privledges, otherwise hit cancel.");
 	db->removeDatabase(dbname);
 	return false;
       }	  
-      q=new QSqlQuery("drop database Rivendell");
+      q=new RDSqlQuery("drop database Rivendell");
       delete q;
-      q=new QSqlQuery("create database Rivendell");
+      q=new RDSqlQuery("create database Rivendell");
       if(!q->isActive()) {   // Can't create DB.
 	delete q;
 	QMessageBox::warning(NULL,QT_TR_NOOP("Can't Create DB"),
@@ -315,7 +315,7 @@ with administrative privledges, otherwise hit cancel.");
       sql=QString().
 	sprintf("grant all on %s to %s identified by \"%s\"",
 		(const char *)dbname,(const char *)login,(const char *)pwd);
-      q=new QSqlQuery(sql);
+      q=new RDSqlQuery(sql);
       if(!q->isActive()) {  // Can't authorize DB.
 	QMessageBox::warning(NULL,QT_TR_NOOP("Can't Create DB"),
 		  QT_TR_NOOP("Unable to authorize a Rivendell Database!"));
