@@ -237,6 +237,10 @@ been updated to Version</source>
         <source>Matrix already exists!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Axia LiveWire</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>AddReport</name>
@@ -950,10 +954,6 @@ Do you still want to save?</source>
         <source>Description:</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Connection Type:</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Serial</source>
         <translation type="unfinished"></translation>
@@ -982,10 +982,6 @@ Do you still want to save?</source>
         <source>Password:</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Port:</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Inputs:</source>
         <translation type="unfinished"></translation>
@@ -1053,7 +1049,44 @@ Displays</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>The IP address is invalid!</source>
+        <source>LiveWire
+Nodes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Primary Connection</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Backup Connection</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Type:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Serial Port:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>None</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The primary IP address is invalid!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The backup IP address is invalid!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Duplicate Connections</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The primary and backup connections must be different!</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1572,6 +1605,18 @@ in order to populate the audio resources database.</source>
         <source>320 kbps/chan</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>No</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Yes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Allow E&amp;xternal Editing:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditReport</name>
@@ -1823,6 +1868,14 @@ Variables</source>
         <source>The Heartbeat Cart number is invalid!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Editor &amp;Command:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use Realtime Filtering</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditSvc</name>
@@ -2176,10 +2229,6 @@ must be saved.  Save now?</source>
         <source>Configure System Panels</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Assign Group Permissions</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>&amp;OK</source>
         <translation type="unfinished"></translation>
@@ -2188,6 +2237,36 @@ must be saved.  Save now?</source>
         <source>&amp;Cancel</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Podcasting Rights</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cre&amp;ate Podcast</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>E&amp;dit Podcast</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Dele&amp;te Podcast</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Assign Group
+Permissions</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Assign Podcast Feed
+Permissions</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Allow Web Logins</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditVguestResource</name>
@@ -2376,6 +2455,14 @@ PARTICULAR PURPOSE.  Touch the &quot;View License&quot; button for details.</sou
         <source>right</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>NODE</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>#</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ListGpis</name>
@@ -2633,6 +2720,10 @@ PARTICULAR PURPOSE.  Touch the &quot;View License&quot; button for details.</sou
         <source>Unknown</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Axia LiveWire</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ListReports</name>
@@ -2935,6 +3026,11 @@ Do you want to continue?</source>
         <source>Restore completed successfully.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Manage
+&amp;Feeds</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MySqlLogin</name>
