@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: list_log.cpp,v 1.97 2007/09/14 14:06:48 fredg Exp $
+//      $Id: list_log.cpp,v 1.98 2007/10/04 20:53:32 dmills Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -24,7 +24,7 @@
 #include <qpixmap.h>
 #include <qpainter.h>
 #include <qmessagebox.h>
-
+#include <rddb.h>
 #include <rdconf.h>
 #include <rdlistviewitem.h>
 #include <rddebug.h>
@@ -671,7 +671,7 @@ void ListLog::loadButtonData()
 
   RDLog *edit_log;
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
 
   ListLogs *logs=new ListLogs(&name,&svcname,list_log,this,"list_logs");
   switch(logs->exec()) {
@@ -700,7 +700,7 @@ void ListLog::loadButtonData()
 			      (const char *)name,
 			      (const char *)rdripc->user(),
 			      (const char *)svcname);
-	q=new QSqlQuery(sql);
+	q=new RDSqlQuery(sql);
 	if(!q->isActive()) {
 	  QMessageBox::warning(this,tr("Log Exists"),
 			       tr("Log Already Exists!"));
