@@ -2,9 +2,9 @@
 //
 // The On Air Playout Utility for Rivendell.
 //
-//   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdairplay.cpp,v 1.157 2007/07/10 16:02:22 fredg Exp $
+//      $Id: rdairplay.cpp,v 1.166 2007/12/31 18:49:09 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -31,7 +31,6 @@
 #include <qapplication.h>
 #include <qwidget.h>
 #include <qpainter.h>
-#include <qsqldatabase.h>
 #include <qsqlpropertymap.h>
 #include <qmessagebox.h>
 #include <qpushbutton.h>
@@ -43,8 +42,7 @@
 #include <qpainter.h>
 
 #include <rd.h>
-#include <rconf.h>
-
+#include <rdconf.h>
 #include <rdairplay.h>
 #include <rdstation.h>
 #include <rdaudio_port.h>
@@ -57,9 +55,9 @@
 #include <rdcart_dialog.h>
 #include <rdmacro.h>
 #include <rdcmd_switch.h>
-#include <rddbheartbeat.h>
 #include <rdgetpasswd.h>
 #include <rddatedecode.h>
+#include <rddb.h>
 
 #include <wall_clock.h>
 #include <globals.h>
@@ -74,6 +72,7 @@ RDUser *rduser;
 RDRipc *rdripc;
 RDCae *rdcae;
 RDEventPlayer *rdevent_player;
+RDCartDialog *rdcart_dialog;
 
 //
 // Icons
@@ -86,6 +85,11 @@ RDEventPlayer *rdevent_player;
 void SigHandler(int signo);
 
 
+void MainWidget::logLine (QString s)
+{
+  LogLine (s);
+}
+
 MainWidget::MainWidget(QWidget *parent,const char *name)
   :QWidget(parent,name)
 {
@@ -98,8 +102,8 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   // Ensure Single Instance
   //
-  air_lock=new RInstanceLock(QString().sprintf("%s/.rdairplaylock",
-					       (const char *)RHomeDir()));
+  air_lock=new RDInstanceLock(QString().sprintf("%s/.rdairplaylock",
+					       (const char *)RDHomeDir()));
   if(!air_lock->lock()) {
     QMessageBox::information(this,tr("RDAirPlay"),
 			     tr("Multiple instances not allowed!"));
@@ -205,23 +209,16 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   // Open Database
   //
-  air_db=QSqlDatabase::addDatabase(air_config->mysqlDriver());
-  if(!air_db) {
+  QString err;
+  QSqlDatabase *db = RDInitDb (&err);
+  if(!db) {
     QMessageBox::warning(this,tr("Database Error"),
-		  tr("Can't Connect","Unable to connect to mySQL Server!"));
+			 //tr("Can't Connect","Unable to connect to mySQL Server!"));
+			 err);
     exit(0);
   }
-  air_db->setDatabaseName(air_config->mysqlDbname());
-  air_db->setUserName(air_config->mysqlUsername());
-  air_db->setPassword(air_config->mysqlPassword());
-  air_db->setHostName(air_config->mysqlHostname());
-  if(!air_db->open()) {
-    QMessageBox::warning(this,tr("Can't Connect"),
-			 tr("Unable to connect to mySQL Server!"));
-    air_db->removeDatabase(air_config->mysqlDbname());
-    exit(0);
-  }
-  new RDDbHeartbeat(air_config->mysqlHeartbeatInterval(),this);
+  connect (RDDbStatus(),SIGNAL(logText(QString)),this,SLOT(logLine(QString))); 
+
 
   //
   // Master Clock Timer
@@ -245,6 +242,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   rdairplay_conf->setExitCode(RDAirPlayConf::ExitDirty);
   air_clear_filter=rdairplay_conf->clearFilter();
   air_bar_action=rdairplay_conf->barAction();
+  air_editor_cmd=rdstation_conf->editorPath();
 
   //
   // Set Audio Assignments
@@ -292,6 +290,8 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
     connect(air_log[i],SIGNAL(reloaded()),reload_mapper,SLOT(map()));
     rename_mapper->setMapping(air_log[i],i);
     connect(air_log[i],SIGNAL(renamed()),rename_mapper,SLOT(map()));
+    connect(air_log[i],SIGNAL(refreshStatusChanged(bool)),
+	    this,SLOT(refreshStatusChangedData(bool)));
   }
   connect(air_log[0],SIGNAL(transportChanged()),
 	  this,SLOT(transportChangedData()));
@@ -299,6 +299,8 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   // Audio Channel Assignments
   //
+  air_cue_card=rdairplay_conf->card(3);
+  air_cue_port=rdairplay_conf->port(3);
   for(int i=0;i<3;i++) {
     air_meter_card[i]=rdairplay_conf->card(i);
     air_meter_port[i]=rdairplay_conf->port(i);
@@ -331,6 +333,15 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   }
   air_log[2]->setChannels(cards,ports,start_rmls,stop_rmls);
 
+  //
+  // Cart Picker
+  //
+  rdcart_dialog=new RDCartDialog(&air_add_filter,&air_add_group,
+				 air_cue_card,air_cue_port,0,0,
+				 rdcae,rdripc,rdstation_conf,
+				 rdstation_conf->editorPath(),
+				 this,"rdcart_dialog");
+
   //
   // Wall Clock
   //
@@ -375,10 +386,10 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   // Audio Meter
   //
-  air_stereo_meter=new RStereoMeter(this,"air_stereo_meter");
+  air_stereo_meter=new RDStereoMeter(this,"air_stereo_meter");
   air_stereo_meter->setGeometry(50,70,air_stereo_meter->sizeHint().width(),
 				air_stereo_meter->sizeHint().height());
-  air_stereo_meter->setMode(RSegMeter::Peak);
+  air_stereo_meter->setMode(RDSegMeter::Peak);
  air_stereo_meter->setFocusPolicy(QWidget::NoFocus);
   if(air_config->useStreamMeters()) {
     air_stereo_meter->hide();
@@ -387,7 +398,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   // Message Label
   //
-  air_message_label=new RLabel(this,"air_message_label");
+  air_message_label=new RDLabel(this,"air_message_label");
   air_message_label->setGeometry(sizeHint().width()-425,70,
 		MESSAGE_WIDGET_WIDTH,air_stereo_meter->sizeHint().height());
   air_message_label->setWordWrapEnabled(true);
@@ -445,7 +456,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   // Add Button
   //
-  air_add_button=new RPushButton(this,"air_add_button");
+  air_add_button=new RDPushButton(this,"air_add_button");
   air_add_button->setGeometry(10,sizeHint().height()-65,80,60);
   air_add_button->setFont(button_font);
   air_add_button->setText(tr("ADD"));
@@ -455,7 +466,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   // Delete Button
   //
-  air_delete_button=new RPushButton(this,"air_delete_button");
+  air_delete_button=new RDPushButton(this,"air_delete_button");
   air_delete_button->setGeometry(100,sizeHint().height()-65,80,60);
   air_delete_button->setFont(button_font);
   air_delete_button->setText(tr("DEL"));
@@ -466,7 +477,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   // Move Button
   //
-  air_move_button=new RPushButton(this,"air_move_button");
+  air_move_button=new RDPushButton(this,"air_move_button");
   air_move_button->setGeometry(190,sizeHint().height()-65,80,60);
   air_move_button->setFont(button_font);
   air_move_button->setText(tr("MOVE"));
@@ -477,14 +488,25 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   // Copy Button
   //
-  air_copy_button=new RPushButton(this,"air_copy_button");
+  air_copy_button=new RDPushButton(this,"air_copy_button");
   air_copy_button->setGeometry(280,sizeHint().height()-65,80,60);
   air_copy_button->setFont(button_font);
   air_copy_button->setText(tr("COPY"));
   air_copy_button->setFlashColor(AIR_FLASH_COLOR);
- air_copy_button->setFocusPolicy(QWidget::NoFocus);
+  air_copy_button->setFocusPolicy(QWidget::NoFocus);
   connect(air_copy_button,SIGNAL(clicked()),this,SLOT(copyButtonData()));
 
+  //
+  // Refresh Indicator
+  //
+  air_refresh_label=new RDLabel(this,"air_refresh_label");
+  air_refresh_label->setGeometry(390,sizeHint().height()-65,120,60);
+  air_refresh_label->setFont(button_font);
+  QPalette p=palette();
+  p.setColor(QColorGroup::Foreground,red);
+  air_refresh_label->setPalette(p);
+  air_refresh_label->setAlignment(AlignCenter);
+
   //
   // Meter Timer
   //
@@ -504,8 +526,8 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
 		       rdairplay_conf->panels(RDAirPlayConf::UserPanel),
 		       rdairplay_conf->flashPanel(),
 		       rdairplay_conf->buttonLabelTemplate(),false,
-		       rdevent_player,
-		       rdripc,rdcae,rdstation_conf,this,"air_panel");
+		       rdevent_player,rdripc,rdcae,rdstation_conf,
+		       rdcart_dialog,this,"air_panel");
     air_panel->setLogfile(air_config->airplayLogname());
     air_panel->setGeometry(510,140,air_panel->sizeHint().width(),
 			 air_panel->sizeHint().height());
@@ -595,8 +617,8 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
     air_panel->setSvcName(rdairplay_conf->defaultSvc());
     connect(rdripc,SIGNAL(userChanged()),air_panel,SLOT(changeUser()));
     connect(air_master_timer,SIGNAL(timeout()),air_panel,SLOT(tickClock()));
-    connect(air_panel,SIGNAL(selectClicked(unsigned)),
-	    this,SLOT(selectClickedData(unsigned)));
+    connect(air_panel,SIGNAL(selectClicked(unsigned,int,int)),
+	    this,SLOT(selectClickedData(unsigned,int,int)));
   }
 
   //
@@ -708,7 +730,7 @@ void MainWidget::ripcConnected(bool state)
   QString logname;
   QHostAddress addr;
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   RDMacro rml;
   rml.setRole(RDMacro::Cmd);
   addr.setAddress("127.0.0.1");
@@ -772,7 +794,7 @@ void MainWidget::ripcConnected(bool state)
     if(!air_start_logname[i].isEmpty()) {
       sql=QString().sprintf("select NAME from LOGS where NAME=\"%s\"",
 			    (const char *)air_start_logname[i]);
-      q=new QSqlQuery(sql);
+      q=new RDSqlQuery(sql);
       if(q->first()) {
 	rml.setCommand(RDMacro::LL);  // Load Log
 	rml.setArgQuantity(2);
@@ -1172,7 +1194,7 @@ void MainWidget::selectClickedData(int id,int line,RDLogLine::Status status)
 }
 
 
-void MainWidget::selectClickedData(unsigned cartnum)
+void MainWidget::selectClickedData(unsigned cartnum,int row,int col)
 {
   switch(air_action_mode) {
       case StartButton::CopyFrom:
@@ -1182,6 +1204,24 @@ void MainWidget::selectClickedData(unsigned cartnum)
 	SetActionMode(StartButton::CopyTo);
 	break;
 
+      case StartButton::CopyTo:
+        air_panel->setButton(air_panel->currentType(),air_panel->currentNumber(),
+                             row,col,air_add_cart);
+	SetActionMode(StartButton::Stop);
+	break;
+
+      case StartButton::AddTo:
+        air_panel->setButton(air_panel->currentType(),air_panel->currentNumber(),
+                             row,col,air_add_cart);
+	SetActionMode(StartButton::Stop);
+	break;
+
+      case StartButton::DeleteFrom:
+        air_panel->setButton(air_panel->currentType(),air_panel->currentNumber(),
+                             row,col,0);
+	SetActionMode(StartButton::Stop);
+	break;
+
       default:
 	break;
   }
@@ -1354,6 +1394,18 @@ void MainWidget::timeModeData(RDAirPlayConf::TimeMode mode)
 }
 
 
+void MainWidget::refreshStatusChangedData(bool active)
+{
+  if(active) {
+    air_refresh_label->setText(tr("LOG\nREFRESHING"));
+  }
+  else {
+    air_refresh_label->setText("");
+  }
+  qApp->processEvents();
+}
+
+
 void MainWidget::keyPressEvent(QKeyEvent *e)
 {
  switch(e->key()) {
@@ -1410,7 +1462,6 @@ void MainWidget::closeEvent(QCloseEvent *e)
       return;
     }
     rdairplay_conf->setExitCode(RDAirPlayConf::ExitClean);
-    air_db->removeDatabase(air_config->mysqlDbname());
     LogLine("RDAirPlay exiting");
     air_lock->unlock();
     exit(0);
@@ -1421,7 +1472,6 @@ void MainWidget::closeEvent(QCloseEvent *e)
     return;
   }
   rdairplay_conf->setExitCode(RDAirPlayConf::ExitClean);
-  air_db->removeDatabase(air_config->mysqlDbname());
   LogLine("RDAirPlay exiting");
   air_lock->unlock();
   exit(0);
@@ -1543,11 +1593,10 @@ void MainWidget::SetLiveAssistMode()
 
 void MainWidget::SetActionMode(StartButton::Mode mode)
 {
-  RDCartDialog *dialog=NULL;
   QString svc_name[RD_MAX_DEFAULT_SERVICES];
   int svc_quan=0;
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
 
   if(air_action_mode==mode) {
     return;
@@ -1582,15 +1631,18 @@ void MainWidget::SetActionMode(StartButton::Mode mode)
 	  sql=QString().sprintf("select SERVICE_NAME from SERVICE_PERMS\
                                  where STATION_NAME=\"%s\"",
 				(const char *)rdstation_conf->name());
-	  q=new QSqlQuery(sql);
+	  q=new RDSqlQuery(sql);
 	  while(q->next()&&svc_quan<(RD_MAX_DEFAULT_SERVICES-1)) {
 	    svc_name[svc_quan++]=q->value(0).toString();
 	  }
 	  delete q;
 	}
+	/*
 	dialog=new RDCartDialog(&air_add_cart,&air_add_filter,&air_add_group,
-				RDCart::All,svc_name,svc_quan,
-				this,"cart_add_dialog");
+				RDCart::All,svc_name,svc_quan,air_cue_card,
+				air_cue_port,0,0,rdcae,rdripc,rdstation_conf,
+				air_editor_cmd,this,"cart_add_dialog");
+	*/
 	air_add_button->setFlashColor(BUTTON_FROM_BACKGROUND_COLOR);
 	air_add_button->setFlashingEnabled(true);
 	air_delete_button->setFlashingEnabled(false);
@@ -1601,7 +1653,7 @@ void MainWidget::SetActionMode(StartButton::Mode mode)
 	}
 	air_button_list->setActionMode(RDAirPlayConf::Normal);
 	air_panel->setActionMode(RDAirPlayConf::Normal);
-	if(dialog->exec()==0) {
+	if(rdcart_dialog->exec(&air_add_cart,RDCart::All,0,0)==0) {
 	  SetActionMode(StartButton::AddTo);
 	}
 	else {
@@ -1690,7 +1742,6 @@ void MainWidget::SetActionMode(StartButton::Mode mode)
       default:
 	break;
   }
-  delete dialog;
 }
 
 
