@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdairplay.h,v 1.71 2007/06/08 23:07:04 fredg Exp $
+//      $Id: rdairplay.h,v 1.77 2007/12/05 20:17:33 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -34,19 +34,18 @@
 #include <qsocketdevice.h>
 #include <qpixmap.h>
 
-#include <rpushbutton.h>
-#include <rstereometer.h>
-#include <rlabel.h>
-#include <rinstancelock.h>
-
+#include <rdpushbutton.h>
+#include <rdstereometer.h>
+#include <rdlabel.h>
+#include <rdinstancelock.h>
 #include <rduser.h>
 #include <rdripc.h>
-#include <log_play.h>
 #include <rdplay_deck.h>
 #include <rdmacro.h>
 #include <rdconfig.h>
 #include <rd.h>
 
+#include <log_play.h>
 #include <loglinebox.h>
 #include <post_counter.h>
 #include <pie_counter.h>
@@ -88,6 +87,7 @@ class MainWidget : public QWidget
   QSizePolicy sizePolicy() const;
 
  private slots:
+  void logLine (QString);
   void ripcConnected(bool state);
   void rmlReceivedData(RDMacro *rml);
   void logRenamedData(int log);
@@ -101,11 +101,12 @@ class MainWidget : public QWidget
   void panelButtonData();
   void modeButtonData();
   void selectClickedData(int id,int line,RDLogLine::Status status);
-  void selectClickedData(unsigned cartnum);
+  void selectClickedData(unsigned cartnum,int row,int col);
   void meterData();
   void masterTimerData();
   void transportChangedData();
   void timeModeData(RDAirPlayConf::TimeMode mode);
+  void refreshStatusChangedData(bool active);
   void keyPressEvent(QKeyEvent *e);
   void keyReleaseEvent(QKeyEvent *e);
   void closeEvent(QCloseEvent *);
@@ -128,18 +129,17 @@ class MainWidget : public QWidget
   RDSoundPanel *air_panel;
   PostCounter *air_post_counter;
   PieCounter *air_pie_counter;
-  RStereoMeter *air_stereo_meter;
+  RDStereoMeter *air_stereo_meter;
   StopCounter *air_stop_counter;
   ModeDisplay *air_mode_display;
-  RPushButton *air_add_button;
-  RPushButton *air_delete_button;
-  RPushButton *air_move_button;
-  RPushButton *air_copy_button;
+  RDPushButton *air_add_button;
+  RDPushButton *air_delete_button;
+  RDPushButton *air_move_button;
+  RDPushButton *air_copy_button;
   QPushButton *air_log_button[RDAIRPLAY_LOG_QUANTITY];
   QPushButton *air_panel_button;
   ListLog *air_log_list[RDAIRPLAY_LOG_QUANTITY];
   ButtonLog *air_button_list;
-  QSqlDatabase *air_db;
   StartButton::Mode air_action_mode;
   QString air_logname;
   QTimer *air_master_timer;
@@ -157,11 +157,13 @@ class MainWidget : public QWidget
   int air_copy_line;
   QString air_add_filter;
   QString air_add_group;
-  RLabel *air_message_label;
+  RDLabel *air_message_label;
   int air_source_id;
   int air_meter_card[3];
   int air_meter_port[3];
-  RInstanceLock *air_lock;
+  int air_cue_card;
+  int air_cue_port;
+  RDInstanceLock *air_lock;
   bool air_clear_filter;
   RDAirPlayConf::BarAction air_bar_action;
   bool air_pause_enabled;
@@ -172,6 +174,8 @@ class MainWidget : public QWidget
   bool air_start_start[RDAIRPLAY_LOG_QUANTITY];
   RDAirPlayConf::ExitCode rdairplay_previous_exit_code;
   QDateTime air_startup_datetime;
+  RDLabel *air_refresh_label;
+  QString air_editor_cmd;
 };
 
 
