@@ -85,6 +85,10 @@
         <source>Overlap</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>No Fade When Segueing At End</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ListLog</name>
@@ -380,19 +384,6 @@ Log</source>
         <source>Database Error</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Can&apos;t Connect</source>
-        <comment>Unable to connect to mySQL Server!</comment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Can&apos;t Connect</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Unable to connect to mySQL Server!</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>ADD</source>
         <translation type="unfinished"></translation>
@@ -437,6 +428,11 @@ Panel</source>
         <source>Multiple instances not allowed!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>LOG
+REFRESHING</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ModeDisplay</name>
