@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_recording.cpp,v 1.43 2007/09/14 14:06:49 fredg Exp $
+//      $Id: edit_recording.cpp,v 1.46 2007/12/31 18:49:09 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -30,8 +30,8 @@
 #include <qevent.h>
 #include <qmessagebox.h>
 #include <qcheckbox.h>
-#include <qsqldatabase.h>
 
+#include <rddb.h>
 #include <rd.h>
 #include <rdcut_dialog.h>
 #include <rdcut_path.h>
@@ -66,9 +66,9 @@ EditRecording::EditRecording(int id,std::vector<int> *adds,QString *filter,
   QFont day_font=QFont("Helvetica",10,QFont::Normal);
   day_font.setPixelSize(10);
 
-  edit_filter=filter;
   edit_deck=NULL;
   edit_added_events=adds;
+  edit_filter=filter;
 
   setCaption(tr("Edit Recording"));
 
@@ -621,7 +621,7 @@ void EditRecording::activateStationData(int id,bool use_temp)
   char station[65];
   char gunk[3];
   int chan;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   
   QString temp=edit_source_box->currentText();
   sscanf((const char *)edit_station_box->currentText(),"%s%s%d",
@@ -634,7 +634,7 @@ void EditRecording::activateStationData(int id,bool use_temp)
     edit_channels_box->setCurrentItem(edit_deck->defaultChannels()-1);
   }
   edit_source_box->clear();
-  q=new QSqlQuery(QString().sprintf("select NAME from INPUTS where \
+  q=new RDSqlQuery(QString().sprintf("select NAME from INPUTS where \
                                     (STATION_NAME=\"%s\")&&(MATRIX=%d)",
 				    (const char *)edit_deck->switchStation(),
 				    edit_deck->switchMatrix()));
@@ -721,8 +721,8 @@ void EditRecording::selectCutData()
 {
   QString str;
 
-  RDCutDialog *cut=new RDCutDialog(&edit_cutname,edit_filter,NULL,
-				   catch_user->name(),false,true);
+  RDCutDialog *cut=new RDCutDialog(&edit_cutname,rdstation_conf,edit_filter,
+				   NULL,catch_user->name(),false,true);
   switch(cut->exec()) {
       case 0:
 	edit_description_edit->setText(RDCutPath(edit_cutname));
@@ -818,7 +818,7 @@ void EditRecording::PopulateDecks(QComboBox *box)
   QString sql=QString("select STATION_NAME,CHANNEL from DECKS \
 where (CARD_NUMBER!=-1)&&(PORT_NUMBER!=-1)&&(CHANNEL!=0) \
 &&(CHANNEL<9) order by STATION_NAME,CHANNEL");
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   while(q->next()) {
     box->insertItem(QString().sprintf("%s : %dR",
 		   (const char *)q->value(0).toString(),q->value(1).toInt()));
@@ -1144,7 +1144,7 @@ bool EditRecording::CheckEvent(bool include_myself)
   if(!include_myself) {
     sql+=QString().sprintf("&&(ID!=%d)",edit_recording->id());
   }
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   bool res=!q->first();
   delete q;
   if(!res) {
@@ -1164,7 +1164,7 @@ QString EditRecording::GetSourceName(int input)
                                  (MATRIX=%d)&&(NUMBER=%d)",
 				(const char *)edit_deck->switchStation(),
 				edit_deck->switchMatrix(),input);
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   if(q->first()) {
     input_name=q->value(0).toString();
   }
@@ -1183,7 +1183,7 @@ int EditRecording::GetSource()
 			       (const char *)edit_deck->switchStation(),
 				edit_deck->switchMatrix(),
 			       (const char *)edit_source_box->currentText());
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   if(q->first()) {
     source=q->value(0).toInt();
   }
