@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_upload.cpp,v 1.9 2007/02/14 21:53:27 fredg Exp $
+//      $Id: edit_upload.cpp,v 1.14 2007/12/31 18:49:10 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -29,12 +29,9 @@
 #include <qevent.h>
 #include <qmessagebox.h>
 #include <qcheckbox.h>
-#include <qsqldatabase.h>
-
-#include <rurl.h>
-#include <rconf.h>
-#include <math.h>
 
+#include <rddb.h>
+#include <rdurl.h>
 #include <rd.h>
 #include <rdcut_dialog.h>
 #include <rdcut_path.h>
@@ -46,11 +43,11 @@
 
 
 EditUpload::EditUpload(int id,std::vector<int> *adds,QString *filter,
-		       QString *group,QWidget *parent,const char *name)
+		       QWidget *parent,const char *name)
   : QDialog(parent,name,true)
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString temp;
 
   //
@@ -71,10 +68,9 @@ EditUpload::EditUpload(int id,std::vector<int> *adds,QString *filter,
   QFont day_font=QFont("Helvetica",10,QFont::Normal);
   day_font.setPixelSize(10);
 
-  edit_filter=filter;
-  edit_group=group;
   edit_deck=NULL;
   edit_added_events=adds;
+  edit_filter=filter;
 
   setCaption(tr("Edit Upload"));
 
@@ -124,18 +120,30 @@ EditUpload::EditUpload(int id,std::vector<int> *adds,QString *filter,
   label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
 
   //
-  // Source
+  // RSS Feed
   //
-  edit_destination_edit=new QLineEdit(this,"edit_destination_edit");
-  edit_destination_edit->setGeometry(115,43,sizeHint().width()-195,20);
-  edit_destination_edit->setReadOnly(true);
-  label=new QLabel(edit_destination_edit,
-		   tr("Source:"),this,"edit_destination_label");
+  edit_feed_box=new QComboBox(this,"edit_feed_box");
+  edit_feed_box->setGeometry(115,43,100,20);
+  edit_feed_box->insertItem(tr("[none]"));
+  label=new QLabel(edit_feed_box,
+		   tr("RSS Feed:"),this,"edit_feed_label");
   label->setGeometry(10,43,100,19);
   label->setFont(label_font);
   label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+
+  //
+  // Source
+  //
+  edit_destination_edit=new QLineEdit(this,"edit_destination_edit");
+  edit_destination_edit->setGeometry(115,70,sizeHint().width()-195,20);
+  edit_destination_edit->setReadOnly(true);
+  label=new QLabel(edit_destination_edit,
+		   tr("Source:"),this,"edit_destination_label");
+  label->setGeometry(10,70,100,19);
+  label->setFont(label_font);
+  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
   QPushButton *button=new QPushButton(this,"destination_button");
-  button->setGeometry(sizeHint().width()-70,41,60,24);
+  button->setGeometry(sizeHint().width()-70,68,60,24);
   button->setFont(day_font);
   button->setText(tr("&Select"));
   connect(button,SIGNAL(clicked()),this,SLOT(selectCartData()));
@@ -144,11 +152,11 @@ EditUpload::EditUpload(int id,std::vector<int> *adds,QString *filter,
   // Description
   //
   edit_description_edit=new QLineEdit(this,"edit_description_edit");
-  edit_description_edit->setGeometry(115,70,sizeHint().width()-125,20);
+  edit_description_edit->setGeometry(115,97,sizeHint().width()-125,20);
   edit_description_edit->setValidator(validator);
   label=new QLabel(edit_description_edit,
 		   tr("Description:"),this,"edit_description_label");
-  label->setGeometry(10,70,100,20);
+  label->setGeometry(10,97,100,20);
   label->setFont(label_font);
   label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
 
@@ -156,13 +164,13 @@ EditUpload::EditUpload(int id,std::vector<int> *adds,QString *filter,
   // Url
   //
   edit_url_edit=new QLineEdit(this,"edit_url_edit");
-  edit_url_edit->setGeometry(115,97,sizeHint().width()-125,20);
+  edit_url_edit->setGeometry(115,124,sizeHint().width()-125,20);
   edit_url_edit->setMaxLength(255);
   edit_url_edit->setValidator(validator);
   connect(edit_url_edit,SIGNAL(textChanged(const QString &)),
 	  this,SLOT(urlChangedData(const QString &)));
   label=new QLabel(edit_url_edit,tr("Url:"),this,"edit_url_label");
-  label->setGeometry(10,97,100,20);
+  label->setGeometry(10,124,100,20);
   label->setFont(label_font);
   label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
 
@@ -170,12 +178,12 @@ EditUpload::EditUpload(int id,std::vector<int> *adds,QString *filter,
   // Username
   //
   edit_username_edit=new QLineEdit(this,"edit_username_edit");
-  edit_username_edit->setGeometry(115,124,150,20);
+  edit_username_edit->setGeometry(115,151,150,20);
   edit_username_edit->setMaxLength(64);
   edit_username_edit->setValidator(validator);
   edit_username_label=new QLabel(edit_username_edit,
 		   tr("Username:"),this,"edit_username_label");
-  edit_username_label->setGeometry(10,124,100,20);
+  edit_username_label->setGeometry(10,151,100,20);
   edit_username_label->setFont(label_font);
   edit_username_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
 
@@ -183,13 +191,13 @@ EditUpload::EditUpload(int id,std::vector<int> *adds,QString *filter,
   // Password
   //
   edit_password_edit=new QLineEdit(this,"edit_password_edit");
-  edit_password_edit->setGeometry(360,124,sizeHint().width()-370,20);
+  edit_password_edit->setGeometry(360,151,sizeHint().width()-370,20);
   edit_password_edit->setEchoMode(QLineEdit::Password);
   edit_password_edit->setMaxLength(64);
   edit_username_edit->setValidator(validator);
   edit_password_label=new QLabel(edit_password_edit,
 		   tr("Password:"),this,"edit_password_label");
-  edit_password_label->setGeometry(275,124,80,20);
+  edit_password_label->setGeometry(275,151,80,20);
   edit_password_label->setFont(label_font);
   edit_password_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
 
@@ -197,15 +205,15 @@ EditUpload::EditUpload(int id,std::vector<int> *adds,QString *filter,
   // Audio Format
   //
   edit_format_edit=new QLineEdit(this,"edit_format_edit");
-  edit_format_edit->setGeometry(115,151,sizeHint().width()-195,20);
+  edit_format_edit->setGeometry(115,178,sizeHint().width()-195,20);
   edit_format_edit->setReadOnly(true);
   label=new QLabel(edit_format_edit,
 		   tr("Export Format:"),this,"edit_format_label");
-  label->setGeometry(5,151,105,20);
+  label->setGeometry(5,178,105,20);
   label->setFont(label_font);
   label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
   button=new QPushButton(this,"format_button");
-  button->setGeometry(sizeHint().width()-70,149,60,24);
+  button->setGeometry(sizeHint().width()-70,176,60,24);
   button->setFont(day_font);
   button->setText(tr("S&et"));
   connect(button,SIGNAL(clicked()),this,SLOT(setFormatData()));
@@ -214,11 +222,11 @@ EditUpload::EditUpload(int id,std::vector<int> *adds,QString *filter,
   // Normalize Check Box
   //
   edit_normalize_box=new QCheckBox(this,"edit_normalize_box");
-  edit_normalize_box->setGeometry(115,181,15,15);
+  edit_normalize_box->setGeometry(115,208,15,15);
   edit_normalize_box->setChecked(true);
   label=new QLabel(edit_normalize_box,tr("Normalize"),
 		   this,"normalize_check_label");
-  label->setGeometry(135,179,83,20);
+  label->setGeometry(135,206,83,20);
   label->setFont(label_font);
   label->setAlignment(AlignLeft|AlignVCenter);
   connect(edit_normalize_box,SIGNAL(toggled(bool)),
@@ -228,15 +236,15 @@ EditUpload::EditUpload(int id,std::vector<int> *adds,QString *filter,
   // Normalize Level
   //
   edit_normalize_spin=new QSpinBox(this,"edit_normalize_spin");
-  edit_normalize_spin->setGeometry(265,179,40,20);
+  edit_normalize_spin->setGeometry(265,206,40,20);
   edit_normalize_spin->setRange(-30,0);
   edit_normalize_label=new QLabel(edit_normalize_spin,tr("Level:"),
 				 this,"normalize_spin_label");
-  edit_normalize_label->setGeometry(215,179,45,20);
+  edit_normalize_label->setGeometry(215,208,45,20);
   edit_normalize_label->setFont(label_font);
   edit_normalize_label->setAlignment(AlignRight|AlignVCenter);
   edit_normalize_unit=new QLabel(tr("dBFS"),this,"normalize_unit_label");
-  edit_normalize_unit->setGeometry(310,179,40,20);
+  edit_normalize_unit->setGeometry(310,208,40,20);
   edit_normalize_unit->setFont(label_font);
   edit_normalize_unit->setAlignment(AlignLeft|AlignVCenter);
 
@@ -244,7 +252,7 @@ EditUpload::EditUpload(int id,std::vector<int> *adds,QString *filter,
   // Button Label
   //
   label=new QLabel(tr("Active Days"),this,"active_days_label");
-  label->setGeometry(47,209,90,19);
+  label->setGeometry(47,236,90,19);
   label->setFont(label_font);
   label->setAlignment(AlignHCenter|ShowPrefix);
 
@@ -252,10 +260,10 @@ EditUpload::EditUpload(int id,std::vector<int> *adds,QString *filter,
   // Monday Button
   //
   edit_mon_button=new QCheckBox(this,"edit_mon_button");
-  edit_mon_button->setGeometry(20,228,20,20);
+  edit_mon_button->setGeometry(20,255,20,20);
   label=new QLabel(edit_mon_button,
 		   tr("Monday"),this,"edit_mon_label");
-  label->setGeometry(40,228,115,20);
+  label->setGeometry(40,255,115,20);
   label->setFont(day_font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
@@ -263,10 +271,10 @@ EditUpload::EditUpload(int id,std::vector<int> *adds,QString *filter,
   // Tuesday Button
   //
   edit_tue_button=new QCheckBox(this,"edit_tue_button");
-  edit_tue_button->setGeometry(115,228,20,20);
+  edit_tue_button->setGeometry(115,255,20,20);
   label=new QLabel(edit_tue_button,
 		   tr("Tuesday"),this,"edit_tue_label");
-  label->setGeometry(135,228,115,20);
+  label->setGeometry(135,255,115,20);
   label->setFont(day_font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
@@ -274,10 +282,10 @@ EditUpload::EditUpload(int id,std::vector<int> *adds,QString *filter,
   // Wednesday Button
   //
   edit_wed_button=new QCheckBox(this,"edit_wed_button");
-  edit_wed_button->setGeometry(215,228,20,20);
+  edit_wed_button->setGeometry(215,255,20,20);
   label=new QLabel(edit_wed_button,
 		   tr("Wednesday"),this,"edit_wed_label");
-  label->setGeometry(235,228,115,20);
+  label->setGeometry(235,255,115,20);
   label->setFont(day_font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
@@ -285,10 +293,10 @@ EditUpload::EditUpload(int id,std::vector<int> *adds,QString *filter,
   // Thursday Button
   //
   edit_thu_button=new QCheckBox(this,"edit_thu_button");
-  edit_thu_button->setGeometry(335,228,20,20);
+  edit_thu_button->setGeometry(335,255,20,20);
   label=new QLabel(edit_thu_button,
 		   tr("Thursday"),this,"edit_thu_label");
-  label->setGeometry(355,228,115,20);
+  label->setGeometry(355,255,115,20);
   label->setFont(day_font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
@@ -296,10 +304,10 @@ EditUpload::EditUpload(int id,std::vector<int> *adds,QString *filter,
   // Friday Button
   //
   edit_fri_button=new QCheckBox(this,"edit_fri_button");
-  edit_fri_button->setGeometry(440,228,20,20);
+  edit_fri_button->setGeometry(440,255,20,20);
   label=new QLabel(edit_fri_button,
 		   tr("Friday"),this,"edit_fri_label");
-  label->setGeometry(460,228,40,20);
+  label->setGeometry(460,255,40,20);
   label->setFont(day_font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
@@ -307,10 +315,10 @@ EditUpload::EditUpload(int id,std::vector<int> *adds,QString *filter,
   // Saturday Button
   //
   edit_sat_button=new QCheckBox(this,"edit_sat_button");
-  edit_sat_button->setGeometry(130,253,20,20);
+  edit_sat_button->setGeometry(130,280,20,20);
   label=new QLabel(edit_sat_button,
 		   tr("Saturday"),this,"edit_sat_label");
-  label->setGeometry(150,253,60,20);
+  label->setGeometry(150,280,60,20);
   label->setFont(day_font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
@@ -318,10 +326,10 @@ EditUpload::EditUpload(int id,std::vector<int> *adds,QString *filter,
   // Sunday Button
   //
   edit_sun_button=new QCheckBox(this,"edit_sun_button");
-  edit_sun_button->setGeometry(300,253,20,20);
+  edit_sun_button->setGeometry(300,280,20,20);
   label=new QLabel(edit_sun_button,
 		   tr("Sunday"),this,"edit_sun_label");
-  label->setGeometry(320,253,60,20);
+  label->setGeometry(320,280,60,20);
   label->setFont(day_font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
@@ -329,10 +337,10 @@ EditUpload::EditUpload(int id,std::vector<int> *adds,QString *filter,
   // OneShot Button
   //
   edit_oneshot_box=new QCheckBox(this,"edit_oneshot_box");
-  edit_oneshot_box->setGeometry(20,288,15,15);
+  edit_oneshot_box->setGeometry(20,315,15,15);
   label=new QLabel(edit_oneshot_box,
 		   tr("Make OneShot"),this,"edit_oneshot_label");
-  label->setGeometry(40,286,115,20);
+  label->setGeometry(40,313,115,20);
   label->setFont(label_font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
@@ -370,7 +378,7 @@ EditUpload::EditUpload(int id,std::vector<int> *adds,QString *filter,
   //
   // Populate Data
   //
-  q=new QSqlQuery("select NAME from STATIONS where NAME!=\"DEFAULT\"");
+  q=new RDSqlQuery("select NAME from STATIONS where NAME!=\"DEFAULT\"");
   while(q->next()) {
     edit_station_box->insertItem(q->value(0).toString());
     if(edit_recording->station()==q->value(0).toString()) {
@@ -409,6 +417,16 @@ EditUpload::EditUpload(int id,std::vector<int> *adds,QString *filter,
     edit_normalize_spin->setValue(edit_recording->normalizationLevel()/1000);
   }
   normalizeCheckData(edit_normalize_box->isChecked());
+  int feed_id=edit_recording->feedId();
+  sql="select ID,KEY_NAME from FEEDS order by KEY_NAME";
+  q=new RDSqlQuery(sql);
+  while(q->next()) {
+    edit_feed_box->insertItem(q->value(1).toString());
+    if(q->value(0).toInt()==feed_id) {
+      edit_feed_box->setCurrentItem(edit_feed_box->count()-1);
+    }
+  }
+  delete q;
 }
 
 
@@ -423,7 +441,7 @@ EditUpload::~EditUpload()
 
 QSize EditUpload::sizeHint() const
 {
-  return QSize(520,363);
+  return QSize(520,390);
 } 
 
 
@@ -465,7 +483,7 @@ void EditUpload::selectCartData()
 {
   QString str;
 
-  RDCutDialog *cut=new RDCutDialog(&edit_cutname,edit_filter);
+  RDCutDialog *cut=new RDCutDialog(&edit_cutname,rdstation_conf,edit_filter);
   switch(cut->exec()) {
       case 0:
 	edit_description_edit->setText(RDCutPath(edit_cutname));
@@ -525,7 +543,7 @@ void EditUpload::okData()
     QMessageBox::warning(this,tr("Invalid URL"),tr("The URL is invalid!"));
     return;
   }
-  RUrl url(edit_url_edit->text());
+  RDUrl url(edit_url_edit->text());
   QString protocol=url.protocol();
   if((protocol!="ftp")&&(protocol!="smb")&&(protocol!="file")) {
     QMessageBox::warning(this,
@@ -557,7 +575,7 @@ void EditUpload::paintEvent(QPaintEvent *e)
 {
   QPainter *p=new QPainter(this);
   p->setPen(QColor(black));
-  p->drawRect(10,217,sizeHint().width()-20,62);
+  p->drawRect(10,244,sizeHint().width()-20,62);
   p->end();
 }
 
@@ -652,6 +670,7 @@ void EditUpload::Save()
   else {
     edit_recording->setNormalizationLevel(1);
   }
+  edit_recording->setFeedId(edit_feed_box->currentText());
 }
 
 
@@ -692,7 +711,7 @@ bool EditUpload::CheckEvent(bool include_myself)
   if(!include_myself) {
     sql+=QString().sprintf("&&(ID!=%d)",edit_recording->id());
   }
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   bool res=!q->first();
   delete q;
 
