@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdcatchd.cpp,v 1.114 2007/09/14 14:06:52 fredg Exp $
+//      $Id: rdcatchd.cpp,v 1.125 2007/11/06 16:25:56 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -39,6 +39,7 @@
 #include <qsignalmapper.h>
 #include <qsessionmanager.h>
 
+#include <rddb.h>
 #include <rdconf.h>
 #include <rdurl.h>
 #include <rdwavefile.h>
@@ -54,7 +55,8 @@
 #include <rddatedecode.h>
 #include <rdcmd_switch.h>
 #include <rdescape_string.h>
-#include <rddbheartbeat.h>
+#include <rdpodcast.h>
+#include <rdconfig.h>
 
 
 // Logging function that works within and outside the MainObject. 
@@ -120,7 +122,7 @@ MainObject::MainObject(QObject *parent,const char *name)
   :QObject(parent,name)
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
 
   //
   // Read Command Options
@@ -201,24 +203,15 @@ MainObject::MainObject(QObject *parent,const char *name)
   //
   // Open Database
   //
-  catch_db=QSqlDatabase::addDatabase(catch_config->mysqlDriver());
-  if(!catch_db) {
-    LogLine("ERROR rdcatchd aborting - couldn't initialize QSql driver");
-    printf("rdcatchd: aborting - couldn't initialize QSql driver\n");
-    exit(1);
-  }
-  catch_db->setDatabaseName(catch_config->mysqlDbname());
-  catch_db->setUserName(catch_config->mysqlUsername());
-  catch_db->setPassword(catch_config->mysqlPassword());
-  catch_db->setHostName(catch_config->mysqlHostname());
-  if(!catch_db->open()) {
-    LogLine("ERROR rdcatchd aborting - couldn't open mySQL connection");
-    printf("rdcatchd: aborting - couldn't open mySQL connection");
-    catch_db->removeDatabase(catch_config->mysqlDbname());
-    exit(1);
-  }
-  new RDDbHeartbeat(catch_config->mysqlHeartbeatInterval());
+  QString err (tr("ERROR rdcatchd aborting - "));
 
+  catch_db=RDInitDb (&err);
+  if(!catch_db) {
+    LogLine(err);
+    printf(err.ascii());
+    exit(1);
+  }
+  connect (RDDbStatus(),SIGNAL(logText(QString)),this,SLOT(log(QString)));
   //
   // Create RDCatchConf
   //
@@ -287,7 +280,7 @@ MainObject::MainObject(QObject *parent,const char *name)
                          where (STATION_NAME=\"%s\")&&\
                          (CARD_NUMBER!=-1)&&(CHANNEL>0)&&(CHANNEL<9)",
 			(const char *)catch_config->stationName());
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     if((q->value(1).toInt()>=0)&&(q->value(2).toInt()>=0)) {
       catch_record_deck_status[q->value(0).toUInt()-1]=RDDeck::Idle;
@@ -306,7 +299,7 @@ MainObject::MainObject(QObject *parent,const char *name)
                          (DEFAULT_MONITOR_ON=\"Y\")",
 			(const char *)catch_config->stationName(),
 			MAX_DECKS);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     catch_cae->setPassthroughVolume(q->value(0).toInt(),q->value(1).toInt(),
 				    q->value(2).toInt(),0);
@@ -373,7 +366,7 @@ MainObject::MainObject(QObject *parent,const char *name)
 			RDRecording::Downloading,
 			RDRecording::RecordActive,
 			(const char *)catch_config->stationName());
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
   sql=QString().sprintf("update RECORDINGS set EXIT_CODE=%d\
                          where ((EXIT_CODE=%d)||(EXIT_CODE=%d))&&\
@@ -382,7 +375,7 @@ MainObject::MainObject(QObject *parent,const char *name)
 			RDRecording::Waiting,
 			RDRecording::PlayActive,
 			(const char *)catch_config->stationName());
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 
   //
@@ -395,6 +388,11 @@ MainObject::MainObject(QObject *parent,const char *name)
   LogLine("rdcatchd ready");
 }
 
+void MainObject::log (QString msg)
+{
+  LogLine (msg);
+}
+
 
 void MainObject::newConnection(int fd)
 {
@@ -563,7 +561,7 @@ void MainObject::engineData(int id)
   }
 
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   RDStation *rdstation;
   int event=GetEvent(id);
 
@@ -640,7 +638,7 @@ void MainObject::engineData(int id)
                          where (STATION_NAME=\"%s\")&&(CHANNEL=%d)",
 			      (const char *)catch_config->stationName(),
 			      catch_events[event].channel());
-	q=new QSqlQuery(sql);
+	q=new RDSqlQuery(sql);
 	if(q->first()) {
 	  catch_record_card[catch_events[event].channel()-1]=
 	    q->value(0).toInt();
@@ -719,7 +717,7 @@ void MainObject::engineData(int id)
                          from DECKS where (STATION_NAME=\"%s\")&&(CHANNEL=%d)",
 			      (const char *)catch_config->stationName(),
 			      catch_events[event].channel());
-	q=new QSqlQuery(sql);
+	q=new RDSqlQuery(sql);
 	if(q->first()) {
 	  catch_playout_id[catch_events[event].channel()-129]=id;
 	  catch_playout_card[catch_events[event].channel()-129]=
@@ -781,7 +779,7 @@ void MainObject::engineData(int id)
                                RIPPER_LEVEL\
                                from RDLIBRARY where STATION=\"%s\"",
 			      (const char *)catch_config->stationName());
-	q=new QSqlQuery(sql);
+	q=new RDSqlQuery(sql);
 	if(q->first())
 	{
 	  catch_default_format=q->value(0).toInt();
@@ -1255,9 +1253,9 @@ bool MainObject::StartRecording(int event)
     cut_name=QString().sprintf("rdcatchd-record-%d",catch_events[event].id());
     catch_events[event].
       setTempName(QString().sprintf("%s/rdcatchd-record-%d.%s",
-				    (const char *)RD_AUDIO_ROOT,
+				    RDConfiguration()->audioRoot().ascii(),
 				    catch_events[event].id(),
-				    RD_AUDIO_EXTENSION));
+				    RDConfiguration()->audioExtension().ascii()));
     catch_events[event].setDeleteTempFile(true);
     format=RDCae::Pcm16;
   }    
@@ -1354,7 +1352,7 @@ void MainObject::StartPlayout(int event)
   QString sql=QString().sprintf("select START_POINT,END_POINT from CUTS\
                                  where CUT_NAME=\"%s\"",
 				(const char *)catch_events[event].cutName());
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   if(!q->first()) {
     return;
   }
@@ -1489,19 +1487,22 @@ void MainObject::StartDownloadEvent(int event)
     if(protocol=="ftp") {
       catch_events[event].setTempName(BuildTempName(event,"download"));
       catch_events[event].setDeleteTempFile(true);
-      xload_cmd=QString().sprintf("ftp -o %s ftp://",
-			       (const char *)catch_events[event].tempName());
+      xload_cmd=QString().sprintf("lftp -e \"get -O %s %s -o %s;bye\"",
+		  (const char *)RDGetPathPart(catch_events[event].tempName()),
+		  (const char *)url.path().right(url.path().length()-1),
+		  (const char *)RDGetBasePart(catch_events[event].tempName()));
       if(!catch_events[event].urlUsername().isEmpty()) {
-	xload_cmd+=QString().sprintf("%s",(const char *)
-				     catch_events[event].urlUsername());
-	if(!catch_events[event].urlPassword().isEmpty()) {
-	  xload_cmd+=QString().sprintf(":\"%s\"",(const char *)
-				       catch_events[event].urlPassword());
+	xload_cmd+=QString().sprintf(" -u \"%s",
+			  (const char *)catch_events[event].urlUsername());
+	if(catch_events[event].urlPassword().isEmpty()) {
+	  xload_cmd+="\"";
+	}
+	else {
+	  xload_cmd+=QString().sprintf(",%s\"",
+			  (const char *)catch_events[event].urlPassword());
 	}
-	xload_cmd+="@";
       }
-      xload_cmd+=QString().sprintf("\"%s%s\"",(const char *)url.host(),
-			       (const char *)url.path());
+      xload_cmd+=QString().sprintf(" %s",(const char *)url.host());
     }
     if(protocol=="smb") {
       if(!url.validSmbShare()) {
@@ -1599,20 +1600,33 @@ void MainObject::StartUploadEvent(int event)
     if(protocol=="ftp") {
       catch_events[event].setTempName(BuildTempName(event,"upload"));
       catch_events[event].setDeleteTempFile(true);
-      xload_cmd="ftp -u ftp://";
-      if(!catch_events[event].urlUsername().isEmpty()) {
-	xload_cmd+=QString().sprintf("%s",(const char *)
-				     catch_events[event].urlUsername());
-	if(!catch_events[event].urlPassword().isEmpty()) {
-	  xload_cmd+=QString().sprintf(":\"%s\"",(const char *)
-				       catch_events[event].urlPassword());
-	}
-	xload_cmd+="@";
+      QString dir=RDGetPathPart(url.path());
+      if(dir=="/") {
+	dir="//";
       }
-      xload_cmd+=QString().sprintf("%s%s %s",(const char *)url.host(),
-				   (const char *)url.path(),
-				   (const char *)catch_events[event].
-				   tempName());
+      if(dir.right(dir.length()-1)=="/") {
+	xload_cmd=QString().sprintf("lftp -e \"put %s -o %s;bye\"",
+			     (const char *)catch_events[event].tempName(),
+			     (const char *)RDGetBasePart(url.path()));
+      }
+      else {
+	xload_cmd=QString().sprintf("lftp -e \"put -O %s %s -o %s;bye\"",
+			     (const char *)dir.right(dir.length()-1),
+			     (const char *)catch_events[event].tempName(),
+			     (const char *)RDGetBasePart(url.path()));
+      }
+      if(!catch_events[event].urlUsername().isEmpty()) {
+	xload_cmd+=QString().sprintf(" -u \"%s",
+			  (const char *)catch_events[event].urlUsername());
+	if(catch_events[event].urlPassword().isEmpty()) {
+	  xload_cmd+="\"";
+	}
+	else {
+	  xload_cmd+=QString().sprintf(",%s\"",
+			  (const char *)catch_events[event].urlPassword());
+	}
+      }
+      xload_cmd+=QString().sprintf(" %s",(const char *)url.host());
     }
     if(protocol=="smb") {
       if(!url.validSmbShare()) {
@@ -1663,7 +1677,20 @@ void MainObject::StartUploadEvent(int event)
 			      (const char *)catch_events[event].cutName(),
 			      (const char *)catch_events[event].tempName(),
 			      catch_events[event].id()));
-    
+    //
+    // Load Podcast Parameters
+    //
+    if(catch_events[event].feedId()>0) {
+      QFile *file=new QFile(catch_events[event].tempName());
+      catch_events[event].setPodcastLength(file->size());
+      delete file;
+      RDWaveFile *wave=new RDWaveFile(catch_events[event].tempName());
+      if(wave->openWave()) {
+	catch_events[event].setPodcastTime(wave->getExtTimeLength());
+      }
+      delete wave;
+    }
+
     //
     // Execute Upload
     //
@@ -1684,7 +1711,7 @@ void MainObject::StartUploadEvent(int event)
 				  (const char *)catch_events[event].tempName(),
 				  catch_events[event].id()));
 	unlink(QString().sprintf("%s.%s",(const char *)temp_exportname,
-				 RD_AUDIO_EXTENSION));
+				 RDConfiguration()->audioExtension().ascii()));
 	unlink(temp_exportname+".dat");
 	SendExitErrorMessage(&catch_events[event],
 			     tr("server error or invalid URL"),
@@ -1701,6 +1728,9 @@ void MainObject::StartUploadEvent(int event)
     //
     // Clean Up
     //
+    if(catch_events[event].feedId()>0) {
+      CheckInPodcast(&(catch_events[event]));
+    }
     if(catch_events[event].deleteTempFile()) {
       unlink(catch_events[event].tempName());
       LogLine(QString().sprintf("deleted file %s",
@@ -2081,7 +2111,7 @@ void MainObject::EchoArgs(int ch,const char append)
 
 void MainObject::LoadEngine(bool adv_day)
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   catch_events.clear();
@@ -2095,21 +2125,21 @@ void MainObject::LoadEngine(bool adv_day)
                          START_OFFSET,END_TYPE,END_TIME,END_LENGTH,\
                          END_MATRIX,END_LINE,URL,URL_USERNAME,URL_PASSWORD,\
                          QUALITY,NORMALIZE_LEVEL,ALLOW_MULT_RECS,\
-                         MAX_GPI_REC_LENGTH,DESCRIPTION \
+                         MAX_GPI_REC_LENGTH,DESCRIPTION,FEED_ID \
                          from RECORDINGS where STATION_NAME=\"%s\"",
 			(const char *)catch_rdstation->name());
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     catch_events.push_back(CatchEvent());
     LoadEvent(q,&catch_events.back());
   }
-  LogLine(QString().sprintf("loaded %d events",catch_events.size()));
+  LogLine(QString().sprintf("loaded %d events",(int)catch_events.size()));
   delete q;
   LogLine("rdcatchd engine load ends");
 }
 
 
-void MainObject::LoadEvent(QSqlQuery *q,CatchEvent *e)
+void MainObject::LoadEvent(RDSqlQuery *q,CatchEvent *e)
 {
   e->setId(q->value(0).toUInt());
   e->setIsActive(RDBool(q->value(1).toString()));
@@ -2157,6 +2187,7 @@ void MainObject::LoadEvent(QSqlQuery *q,CatchEvent *e)
   e->setAllowMultipleRecordings(RDBool(q->value(42).toString()));
   e->setMaxGpiRecordLength(q->value(43).toUInt());
   e->setDescription(q->value(44).toString());
+  e->setFeedId(q->value(45).toUInt());
 
   if(e->startType()==RDRecording::GpiStart) {
     e->setGpiStartTimer(new QTimer(this));
@@ -2187,7 +2218,7 @@ void MainObject::LoadDeckList()
                                  where (STATION_NAME=\"%s\")&&\
                                  (CARD_NUMBER!=-1)&&(CHANNEL>0)&&(CHANNEL<9)",
 				(const char *)catch_config->stationName());
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   while(q->next()) {
     status[q->value(0).toUInt()-1]=RDDeck::Idle;
     catch_record_card[q->value(0).toUInt()-1]=q->value(1).toInt();
@@ -2219,7 +2250,7 @@ void MainObject::LoadDeckList()
   sql=QString().sprintf("select CHANNEL from DECKS \
 where (STATION_NAME=\"%s\")&&(CARD_NUMBER!=-1)&&(CHANNEL>128)&&(CHANNEL<137)",
 				(const char *)catch_config->stationName());
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     status[q->value(0).toUInt()-129]=RDDeck::Idle;
   }
@@ -2277,7 +2308,7 @@ int MainObject::GetFreeEvent()
 
 bool MainObject::AddEvent(int id)
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
   QString day_name;
 
@@ -2294,10 +2325,10 @@ bool MainObject::AddEvent(int id)
                          START_OFFSET,END_TYPE,END_TIME,END_LENGTH,\
                          END_MATRIX,END_LINE,URL,URL_USERNAME,URL_PASSWORD,\
                          QUALITY,NORMALIZE_LEVEL,ALLOW_MULT_RECS,\
-                         MAX_GPI_REC_LENGTH,DESCRIPTION \
+                         MAX_GPI_REC_LENGTH,DESCRIPTION,FEED_ID \
                          from RECORDINGS where (STATION_NAME=\"%s\")&&(ID=%d)",
 			(const char *)catch_rdstation->name(),id);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   if(q->first()) {
     catch_events.push_back(CatchEvent());
     LoadEvent(q,&catch_events.back());
@@ -2426,7 +2457,7 @@ void MainObject::PurgeEvent(int event)
 {
   QString sql=QString().sprintf("delete from RECORDINGS where ID=%d",
 				catch_events[event].id());
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   delete q;
   BroadcastCommand(QString().sprintf("PE %d!",catch_events[event].id()));
   switch(catch_events[event].type()) {
@@ -2488,7 +2519,7 @@ void MainObject::LoadHeartbeat()
   QString sql=QString().sprintf("select HEARTBEAT_CART,HEARTBEAT_INTERVAL\
                                  from STATIONS where NAME=\"%s\"",
 				(const char *)catch_rdstation->name());
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   if(q->first()) {
     if((q->value(0).toUInt()!=0)&&(q->value(1).toUInt()!=0)) {
       catch_heartbeat_cart=q->value(0).toUInt();
@@ -2506,12 +2537,12 @@ bool MainObject::Export(int event)
   QString export_cmd=GetExportCmd(event,&temp_exportname);
   if(system(export_cmd)!=0) {
     unlink(QString().sprintf("%s.%s",(const char *)temp_exportname,
-			     RD_AUDIO_EXTENSION));
+			     RDConfiguration()->audioExtension().ascii()));
     unlink(temp_exportname+".dat");
     return false;
   }
   unlink(QString().sprintf("%s.%s",(const char *)temp_exportname,
-			   RD_AUDIO_EXTENSION));
+			   RDConfiguration()->audioExtension().ascii()));
   unlink(temp_exportname+".dat");
   return true;
 }
@@ -2528,10 +2559,7 @@ QString MainObject::GetExportCmd(int event,QString *tempname)
 			      (const char *)catch_temp_dir,
 			      catch_events[event].id());
 
-  QString local_filename=
-    QString().sprintf("%s/%s.%s",RD_AUDIO_ROOT,
-		      (const char *)catch_events[event].cutName(),
-		      RD_AUDIO_EXTENSION);
+  QString local_filename=RDCut::pathName(catch_events[event].cutName()); 
   QFile file(local_filename);
   if(!file.exists()) {
     return QString();
@@ -2578,7 +2606,7 @@ QString MainObject::GetExportCmd(int event,QString *tempname)
 	      (const char *)RDEscapeString(catch_events[event].tempName()),
 	      (const char *)(*tempname),
 	      (const char *)(*tempname),
-	      RD_AUDIO_EXTENSION);
+	      RDConfiguration()->audioExtension().ascii());
   }
   else {
     cmd=QString().
@@ -2594,7 +2622,7 @@ QString MainObject::GetExportCmd(int event,QString *tempname)
 	      (const char *)RDEscapeString(catch_events[event].tempName()),
 	      (const char *)(*tempname),
 	      (const char *)(*tempname),
-	      RD_AUDIO_EXTENSION);
+	      RDConfiguration()->audioExtension().ascii());
   }
   // LogLine(QString().sprintf("CMD: %s",(const char *)cmd));
   return cmd;
@@ -2623,12 +2651,12 @@ bool MainObject::Import(int event)
 			      (const char *)catch_events[event].tempName(),
 			      catch_events[event].id()));
     unlink(QString().sprintf("%s.%s",(const char *)temp_importname,
-			     RD_AUDIO_EXTENSION));
+			     RDConfiguration()->audioExtension().ascii()));
     unlink(temp_importname+".dat");
     return false;
   }
   unlink(QString().sprintf("%s.%s",(const char *)temp_importname,
-			   RD_AUDIO_EXTENSION));
+			   RDConfiguration()->audioExtension().ascii()));
   unlink(temp_importname+".dat");
   chown(RDCut::pathName(catch_events[event].cutName()),catch_config->uid(),
 	catch_config->gid());
@@ -2734,7 +2762,7 @@ QString MainObject::GetImportCmd(int event,QString *tempname)
   if(catch_events[event].normalizeLevel()!=0) {
     normal=pow(10.0,(double)(catch_events[event].normalizeLevel()/2000.0));
     cmd=QString().
-      sprintf("rd_import_file %6.4f %d %d %s %d %d %d %d %s/%s.%s %s.dat %s.%s",
+      sprintf("rd_import_file %6.4f %d %d %s %d %d %d %d %s %s.dat %s.%s",
 	      normal,
 	      format_in,
 	      samplerate,
@@ -2743,16 +2771,14 @@ QString MainObject::GetImportCmd(int event,QString *tempname)
 	      catch_events[event].channels(),
 	      catch_events[event].sampleRate(),
 	      catch_events[event].bitrate()/1000,
-	      (const char *)RD_AUDIO_ROOT,
-	      (const char *)catch_events[event].cutName(),
-	      (const char *)RD_AUDIO_EXTENSION,
+	      RDCut::pathName(catch_events[event].cutName()).ascii(),
 	      (const char *)*tempname,
 	      (const char *)*tempname,
-	      (const char *)RD_AUDIO_EXTENSION);
+	      RDConfiguration()->audioExtension().ascii());
   }
   else {
     cmd=QString().
-      sprintf("rd_import_file 0 %d %d %s %d %d %d %d %s/%s.%s %s.dat %s.%s",
+      sprintf("rd_import_file 0 %d %d %s %d %d %d %d %s %s.dat %s.%s",
 	      format_in,
 	      samplerate,
 	      (const char *)RDEscapeString(catch_events[event].tempName()),
@@ -2760,12 +2786,10 @@ QString MainObject::GetImportCmd(int event,QString *tempname)
 	      catch_events[event].channels(),
 	      catch_events[event].sampleRate(),
 	      catch_events[event].bitrate()/1000,
-	      (const char *)RD_AUDIO_ROOT,
-	      (const char *)catch_events[event].cutName(),
-	      (const char *)RD_AUDIO_EXTENSION,
+	      RDCut::pathName(catch_events[event].cutName()).ascii(),
 	      (const char *)*tempname,
 	      (const char *)*tempname,
-	      RD_AUDIO_EXTENSION);
+	      RDConfiguration()->audioExtension().ascii());
   }
   // LogLine(QString().sprintf("CMD: %s",(const char *)cmd));
   return cmd;
@@ -2789,12 +2813,83 @@ void MainObject::CheckInRecording(QString cutname,unsigned threshold)
 }
 
 
+void MainObject::CheckInPodcast(CatchEvent *e)
+{
+  QString sql;
+  RDSqlQuery *q;
+
+  //
+  // Purge Stale Casts
+  //
+  sql=QString().sprintf("delete from PODCASTS where \
+                         (FEED_ID=%d)&&(AUDIO_FILENAME=\"%s\")",
+			e->feedId(),
+			(const char *)RDGetBasePart(e->resolvedUrl()));
+  q=new RDSqlQuery(sql);
+  delete q;
+
+  //
+  // Get Channel Parameters
+  //
+  sql=QString().sprintf("select ENABLE_AUTOPOST,CHANNEL_TITLE,\
+                         CHANNEL_DESCRIPTION,CHANNEL_CATEGORY,\
+                         CHANNEL_LINK,MAX_SHELF_LIFE from FEEDS \
+                         where ID=%u",e->feedId());
+  q=new RDSqlQuery(sql);
+  if(!q->first()) {
+    delete q;
+    return;
+  }
+
+  //
+  // Add the Cast Entry
+  //
+  RDPodcast::Status status=RDPodcast::StatusPending;
+  if(q->value(0).toString().lower()=="y") {
+    status=RDPodcast::StatusActive;
+  }
+  sql=QString().sprintf("insert into PODCASTS set \
+                         FEED_ID=%u,\
+                         STATUS=%u,\
+                         ITEM_TITLE=\"%s\",\
+                         ITEM_DESCRIPTION=\"%s\",\
+                         ITEM_CATEGORY=\"%s\",\
+                         ITEM_LINK=\"%s\",\
+                         AUDIO_FILENAME=\"%s\",\
+                         AUDIO_LENGTH=%u,\
+                         AUDIO_TIME=%u,\
+                         SHELF_LIFE=%u,\
+                         ORIGIN_DATETIME=now()",
+			  e->feedId(),
+			  status,
+			  (const char *)RDEscapeString(q->value(1).toString()),
+			  (const char *)RDEscapeString(q->value(2).toString()),
+			  (const char *)RDEscapeString(q->value(3).toString()),
+			  (const char *)RDEscapeString(q->value(4).toString()),
+			  (const char *)RDGetBasePart(e->resolvedUrl()),
+			  e->podcastLength(),
+			  e->podcastTime(),
+			  q->value(5).toUInt());
+  delete q;
+  q=new RDSqlQuery(sql);
+  delete q;
+
+  //
+  // Update the Build Date
+  //
+  sql=QString().sprintf("update FEEDS set LAST_BUILD_DATETIME=now() \
+                           where ID=%u",e->feedId());
+  q=new RDSqlQuery(sql);
+  delete q;
+}
+
+
 RDRecording::ExitCode MainObject::ReadExitCode(int event)
 {
   RDRecording::ExitCode code=RDRecording::InternalError;
   QString sql=QString().sprintf("select EXIT_CODE from RECORDINGS\
                                  where ID=%d",catch_events[event].id());
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   if(q->first()) {
     code=(RDRecording::ExitCode)q->value(0).toInt();
   }
@@ -2808,7 +2903,7 @@ void MainObject::WriteExitCode(int event,RDRecording::ExitCode code)
 {
   QString sql=QString().sprintf("update RECORDINGS set EXIT_CODE=%d\
                                  where ID=%d",code,catch_events[event].id());
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   delete q;
 }
 
@@ -2817,7 +2912,7 @@ void MainObject::WriteExitCodeById(int id,RDRecording::ExitCode code)
 {
   QString sql=QString().sprintf("update RECORDINGS set EXIT_CODE=%d\
                                  where ID=%d",code,id);
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   delete q;
 }
 
@@ -2943,7 +3038,7 @@ void MainObject::ResolveErrorWildcards(CatchEvent *event,
 void MainObject::StartDropboxes()
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
 
   //
   // Kill Old Instances
@@ -2959,7 +3054,7 @@ void MainObject::StartDropboxes()
                          METADATA_PATTERN,FIX_BROKEN_FORMATS,LOG_PATH \
                          from DROPBOXES where STATION_NAME=\"%s\"",
 			(const char *)catch_config->stationName());
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     QString cmd="nice rdimport --log-mode --drop-box";
     cmd+=
@@ -2980,7 +3075,7 @@ void MainObject::StartDropboxes()
     }
     if(!q->value(8).toString().isEmpty()) {
       cmd+=QString().sprintf(" \"--metadata-pattern=%s\"",
-			     (const char *)q->value(7).toString());
+			     (const char *)q->value(8).toString());
     }
     if(q->value(9).toString()=="Y") {
       cmd+=" --fix-broken-formats";
