@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdcatchd.h,v 1.46 2007/09/14 14:06:52 fredg Exp $
+//      $Id: rdcatchd.h,v 1.49 2007/10/13 16:31:14 dmills Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -105,7 +105,7 @@ class MainObject : public QObject
   void sysHeartbeatData();
   void updateXloadsData();
   void startupCartData();
-  
+  void log (QString);
  private:
   bool StartRecording(int event);
   void StartPlayout(int event);
@@ -123,7 +123,7 @@ class MainObject : public QObject
   void BroadcastCommand(const char *,int except_ch=-1);
   void EchoArgs(int,const char);
   void LoadEngine(bool adv_day=false);
-  void LoadEvent(QSqlQuery *q,CatchEvent *e);
+  void LoadEvent(RDSqlQuery *q,CatchEvent *e);
   void LoadDeckList();
   int GetRecordDeck(int card,int stream);
   int GetPlayoutDeck(int handle);
@@ -139,6 +139,7 @@ class MainObject : public QObject
   bool Import(int event);
   QString GetImportCmd(int event,QString *tempname);
   void CheckInRecording(QString cutname,unsigned threshold);
+  void CheckInPodcast(CatchEvent *e);
   RDRecording::ExitCode ReadExitCode(int event);
   void WriteExitCode(int event,RDRecording::ExitCode code);
   void WriteExitCodeById(int id,RDRecording::ExitCode code);
