@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_chain.cpp,v 1.10 2007/09/08 21:17:37 dmills Exp $
+//      $Id: edit_chain.cpp,v 1.11 2007/10/04 20:53:35 dmills Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -22,7 +22,7 @@
 
 #include <qpushbutton.h>
 #include <qmessagebox.h>
-
+#include <rddb.h>
 #include <edit_chain.h>
 #include <list_logs.h>
 
@@ -303,7 +303,7 @@ void EditChain::labelChangedData(const QString &logname)
   QString sql=
     QString().sprintf("select DESCRIPTION from LOGS where NAME=\"%s\"",
 		      (const char *)logname);
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   if(!q->first()) {
     delete q;
     edit_comment_edit->clear();
