@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_log.cpp,v 1.80 2007/09/14 14:06:56 fredg Exp $
+//      $Id: edit_log.cpp,v 1.82 2007/12/31 18:49:10 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -31,8 +31,8 @@
 #include <qevent.h>
 #include <qmessagebox.h>
 #include <qbuttongroup.h>
-#include <qsqldatabase.h>
 
+#include <rddb.h>
 #include <rdcreate_log.h>
 #include <rddebug.h>
 #include <rdadd_log.h>
@@ -68,7 +68,7 @@ EditLog::EditLog(QString logname,vector<RDLogLine> *clipboard,
   : QDialog(parent,name,true)
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
 
   edit_logname=logname;
   edit_clipboard=clipboard;
@@ -84,13 +84,11 @@ EditLog::EditLog(QString logname,vector<RDLogLine> *clipboard,
   //
   // Config Data
   //
-  RDLogeditConf *conf=new RDLogeditConf(log_config->stationName());
-  edit_default_trans=conf->defaultTransType();
-  edit_output_card=conf->outputCard();
-  edit_output_port=conf->outputPort();
-  edit_start_macro=conf->startCart();
-  edit_end_macro=conf->endCart();
-  delete conf;
+  edit_default_trans=rdlogedit_conf->defaultTransType();
+  edit_output_card=rdlogedit_conf->outputCard();
+  edit_output_port=rdlogedit_conf->outputPort();
+  edit_start_macro=rdlogedit_conf->startCart();
+  edit_end_macro=rdlogedit_conf->endCart();
 
   //
   // Fix the Window Size
@@ -451,7 +449,7 @@ EditLog::EditLog(QString logname,vector<RDLogLine> *clipboard,
   //
   edit_description_edit->setText(edit_log->description());
   sql=QString("select NAME from SERVICES");
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   int n=-1;
   QString service=edit_log->service();
   while(q->next()) {
@@ -955,7 +953,7 @@ void EditLog::saveasData()
   }
   QString logname;
   QString svcname=edit_service_box->currentText();
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
   RDAddLog *log=NULL;
 
@@ -971,7 +969,7 @@ ORIGIN_DATETIME=NOW(),LINK_DATETIME=NOW(),SERVICE=\"%s\"",
 			  (const char *)logname,
 			  (const char *)rdripc->user(),
 			  (const char *)svcname);
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     if(!q->isActive()) {
       QMessageBox::warning(this,tr("Log Exists"),tr("Log Already Exists!"));
       delete q;
