@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdlogedit.cpp,v 1.62 2007/09/14 14:06:56 fredg Exp $
+//      $Id: rdlogedit.cpp,v 1.65 2008/01/02 12:18:39 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -25,11 +25,10 @@
 #include <sys/types.h>
 #include <sys/wait.h>
 #include <unistd.h>
-#endif
+#endif  // WIN32
 #include <qapplication.h>
 #include <qwidget.h>
 #include <qpainter.h>
-#include <qsqldatabase.h>
 #include <qsqlpropertymap.h>
 #include <qmessagebox.h>
 #include <qpushbutton.h>
@@ -44,22 +43,23 @@
 
 #include <rd.h>
 #include <rdconf.h>
-#include <rduser.h>
 #include <rdripc.h>
-#include <rdlogedit.h>
 #include <rdstation.h>
 #include <rdcheck_daemons.h>
 #include <rdcreate_log.h>
 #include <rdadd_log.h>
 #include <rdcmd_switch.h>
-#include <rddbheartbeat.h>
+#include <rddb.h>
 #include <rdtextfile.h>
 #include <rdmixer.h>
 
+
+
+#include <rdlogedit.h>
 #include <edit_log.h>
+#include <globals.h>
 #ifndef WIN32
 #include <voice_tracker.h>
-#include <globals.h>
 #endif  // WIN32
 
 //
@@ -79,6 +79,8 @@ RDStation *rdstation_conf;
 RDUser *rduser;
 RDRipc *rdripc;
 RDConfig *log_config;
+RDLogeditConf *rdlogedit_conf;
+RDCartDialog *log_cart_dialog;
 bool import_running=false;
 #ifndef WIN32
 RDCae *rdcae;
@@ -107,6 +109,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name,WFlags f)
 {
   QString str1;
   QString str2;
+  log_log_list=NULL;
 
   //
   // HACK: Disable the Broken Custom SuSE Dialogs
@@ -146,6 +149,16 @@ MainWidget::MainWidget(QWidget *parent,const char *name,WFlags f)
 			       (const char *)str2));
   log_import_path=RDGetHomeDir();
 
+  //
+  // Open Database
+  //
+  QString err;
+  log_db=RDInitDb(&err);
+  if(!log_db) {
+    QMessageBox::warning(this,tr("Can't Connect"),err);
+    exit(0);
+  }
+
   //
   // CAE Connection
   //
@@ -154,27 +167,6 @@ MainWidget::MainWidget(QWidget *parent,const char *name,WFlags f)
   rdcae->connectHost("localhost",CAED_TCP_PORT,log_config->password());
 #endif  // WIN32
 
-  //
-  // Open Database
-  //
-  log_db=QSqlDatabase::addDatabase(log_config->mysqlDriver());
-  if(!log_db) {
-    QMessageBox::warning(this,tr("Can't Connect"),
-			 tr("Unable to communicate with mySQL Server!"));
-    exit(0);
-  }
-  log_db->setDatabaseName(log_config->mysqlDbname());
-  log_db->setUserName(log_config->mysqlUsername());
-  log_db->setPassword(log_config->mysqlPassword());
-  log_db->setHostName(log_config->mysqlHostname());
-  if(!log_db->open()) {
-    QMessageBox::warning(this,tr("Can't Connect"),
-			 tr("Unable to connect to mySQL Server!"));
-    log_db->removeDatabase(log_config->mysqlDbname());
-    exit(0);
-  }
-  new RDDbHeartbeat(log_config->mysqlHeartbeatInterval(),this);
-
   //
   // Allocate Global Resources
   //
@@ -192,6 +184,28 @@ MainWidget::MainWidget(QWidget *parent,const char *name,WFlags f)
   rdripc=NULL;
 #endif  // WIN32
 
+  //
+  // RDLogEdit Configuration
+  //
+  rdlogedit_conf=new RDLogeditConf(log_config->stationName());
+
+  //
+  // Cart Picker
+  //
+#ifdef WIN32
+  log_cart_dialog=new RDCartDialog(&log_filter,&log_group,-1,-1,0,0,
+				   NULL,NULL,NULL,"",
+				   this,"log_cart_dialog");
+#else
+  log_cart_dialog=new RDCartDialog(&log_filter,&log_group,
+				   rdlogedit_conf->outputCard(),
+				   rdlogedit_conf->outputPort(),
+				   rdlogedit_conf->startCart(),
+				   rdlogedit_conf->endCart(),
+				   rdcae,rdripc,rdstation_conf,"",
+				   this,"log_cart_dialog");
+#endif
+
   //
   // User
   //
@@ -370,7 +384,7 @@ void MainWidget::addData()
 {
   QString logname;
   QString svcname;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
   std::vector<QString> newlogs;
 
@@ -390,7 +404,7 @@ void MainWidget::addData()
 			  (const char *)logname,
 			  (const char *)rdripc->user(),
 			  (const char *)svcname);
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     if(!q->isActive()) {
       QMessageBox::warning(this,tr("Log Exists"),tr("Log Already Exists!"));
       delete q;
@@ -495,7 +509,7 @@ void MainWidget::reportData()
 {
   QString report;
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
 
   //
   // Generate Header
@@ -514,7 +528,7 @@ void MainWidget::reportData()
   sql="select NAME,DESCRIPTION,SERVICE,MUSIC_LINKS,MUSIC_LINKED,\
        TRAFFIC_LINKS,TRAFFIC_LINKED,COMPLETED_TRACKS,SCHEDULED_TRACKS,\
        START_DATE,END_DATE,MODIFIED_DATETIME from LOGS order by NAME";
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     //
     // Summary Status
@@ -628,6 +642,9 @@ void MainWidget::quitMainWidget()
 
 void MainWidget::resizeEvent(QResizeEvent *e)
 {
+  if(log_log_list==NULL) {
+    return;
+  }
   log_log_list->setGeometry(10,10,size().width()-20,size().height()-70);
   log_add_button->setGeometry(10,size().height()-55,80,50);
   log_edit_button->setGeometry(100,size().height()-55,80,50);
@@ -640,7 +657,7 @@ void MainWidget::resizeEvent(QResizeEvent *e)
 
 void MainWidget::RefreshItem(ListListViewItem *item)
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   sql=QString().sprintf("select DESCRIPTION,SERVICE,START_DATE,END_DATE,\
@@ -650,7 +667,7 @@ void MainWidget::RefreshItem(ListListViewItem *item)
                          MODIFIED_DATETIME,AUTO_REFRESH from LOGS\
                          where (TYPE=0)&&(LOG_EXISTS=\"Y\")&&(NAME=\"%s\")",
 			(const char *)item->text(1));
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   if(q->next()) {
     item->setText(2,q->value(0).toString());
     item->setText(3,q->value(1).toString());
@@ -713,13 +730,13 @@ void MainWidget::RefreshItem(ListListViewItem *item)
 
 void MainWidget::RefreshList()
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
   ListListViewItem *item;
 
   log_log_list->clear();
   sql="select NAME from LOGS where (TYPE=0)&&(LOG_EXISTS=\"Y\")";
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     item=new ListListViewItem(log_log_list);
     item->setText(1,q->value(0).toString());
@@ -753,10 +770,6 @@ int main(int argc,char *argv[])
   qt.load(qt_path+QString("qt_")+QTextCodec::locale(),".");
   a.installTranslator(&qt);
 
-  QTranslator libradio(0);
-  libradio.load(tr_path+QString("libradio_")+QTextCodec::locale(),".");
-  a.installTranslator(&libradio);
-
   QTranslator tests(0);
   tests.load(tr_path+QString("rdlogedit_")+QTextCodec::locale(),".");
   a.installTranslator(&tests);
@@ -764,9 +777,10 @@ int main(int argc,char *argv[])
   //
   // Start Event Loop
   //
-  MainWidget *w=new MainWidget(NULL,"main",0);
+  MainWidget *w=new MainWidget(NULL,"main");
   a.setMainWidget(w);
-  w->setGeometry(w->geometry().x(),w->geometry().y(),w->sizeHint().width(),w->sizeHint().height());
+  w->setGeometry(QRect(QPoint(w->geometry().x(),w->geometry().y()),
+		 w->sizeHint()));
   w->show();
   return a.exec();
 }
