@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_perms.cpp,v 1.6 2007/09/14 14:06:58 fredg Exp $
+//      $Id: edit_perms.cpp,v 1.7 2007/10/04 20:53:39 dmills Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -31,11 +31,10 @@
 #include <qmessagebox.h>
 #include <qcheckbox.h>
 #include <qbuttongroup.h>
-#include <qsqldatabase.h>
 
 #include <rduser.h>
 #include <rdpasswd.h>
-
+#include <rddb.h>
 #include <edit_perms.h>
 
 
@@ -44,7 +43,7 @@ EditPerms::EditPerms(QString object_name,ObjectType type,
   : QDialog(parent,name,true)
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString str;
 
   sel_type=type;
@@ -113,13 +112,13 @@ EditPerms::EditPerms(QString object_name,ObjectType type,
 			(const char *)object_type,
 			(const char *)object_type,
 			(const char *)object_name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     svc_object_sel->destInsertItem(q->value(0).toString());
   }
   delete q;
   sql=QString().sprintf("select NAME from SERVICES");
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     if(svc_object_sel->destFindItem(q->value(0).toString())==0) {
       svc_object_sel->sourceInsertItem(q->value(0).toString());
@@ -148,7 +147,7 @@ QSizePolicy EditPerms::sizePolicy() const
 
 void EditPerms::okData()
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   //
@@ -162,7 +161,7 @@ void EditPerms::okData()
 			  (const char *)svc_object_sel->destText(i),
 			  (const char *)object_type,
 			  (const char *)sel_name);
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     if(q->size()==0) {
       delete q;
       sql=QString().
@@ -172,7 +171,7 @@ void EditPerms::okData()
 		(const char *)object_type,
 		(const char *)svc_object_sel->destText(i),
 		(const char *)sel_name);
-      q=new QSqlQuery(sql);
+      q=new RDSqlQuery(sql);
     }
     delete q;
   }
@@ -188,7 +187,7 @@ void EditPerms::okData()
     sql+=QString().sprintf(" && SERVICE_NAME<>\"%s\"",
 			   (const char *)svc_object_sel->destText(i));
   }
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 
   done(0);
