@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: list_clocks.cpp,v 1.22 2007/09/14 14:06:58 fredg Exp $
+//      $Id: list_clocks.cpp,v 1.24 2007/10/05 13:50:33 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -25,10 +25,10 @@
 #include <qtextedit.h>
 #include <qpainter.h>
 #include <qmessagebox.h>
-#include <qsqldatabase.h>
 #include <qpixmap.h>
 #include <qpainter.h>
 
+#include <rddb.h>
 #include <rd.h>
 #include <rdevent.h>
 #include <rdcreate_log.h>
@@ -173,7 +173,7 @@ ListClocks::ListClocks(QString *clockname,QWidget *parent,const char *name)
   //
   edit_filter_box->insertItem(tr("ALL"));
   edit_filter_box->insertItem(tr("NONE"));
-  QSqlQuery *q=new QSqlQuery("select NAME from SERVICES order by NAME");
+  RDSqlQuery *q=new RDSqlQuery("select NAME from SERVICES order by NAME");
   while(q->next()) {
     edit_filter_box->insertItem(q->value(0).toString());
     if(*clock_filter==q->value(0).toString()) {
@@ -211,8 +211,8 @@ void ListClocks::addData()
   QString clockname;
   QString clockname_esc;
   QString sql;
-  QSqlQuery *q;
-  QSqlQuery *q1;
+  RDSqlQuery *q;
+  RDSqlQuery *q1;
   std::vector<QString> new_clocks;
 
   AddClock *add_dialog=new AddClock(&clockname,this,"add_dialog");
@@ -225,7 +225,7 @@ void ListClocks::addData()
   clockname_esc.replace(" ","_");
   sql=QString().sprintf("select NAME from CLOCKS where NAME=\"%s\"",
 			(const char *)clockname);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   if(q->first()) {
     QMessageBox::
       information(this,tr("Clock Exists"),
@@ -236,29 +236,29 @@ void ListClocks::addData()
   delete q;
   sql=QString().sprintf("insert into CLOCKS set NAME=\"%s\",ARTISTSEP=15",
 			(const char *)clockname);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
   sql=RDCreateClockTableSql(clockname);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
   EditClock *clock_dialog=new EditClock(clockname,true,&new_clocks,
 					this,"clock_dialog");
   if(clock_dialog->exec()<0) {
     sql=QString().sprintf("delete from CLOCKS where NAME=\"%s\"",
 			  (const char *)clockname);
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     delete q;
   }
   else {
     if(edit_filter_box->currentItem()==0) {
       sql="select NAME from SERVICES";
-      q=new QSqlQuery(sql);
+      q=new RDSqlQuery(sql);
       while(q->next()) {
 	sql=QString().sprintf("insert into CLOCK_PERMS set\
                                CLOCK_NAME=\"%s\",SERVICE_NAME=\"%s\"",
 			      (const char *)clockname,
 			      (const char *)q->value(0).toString());
-	q1=new QSqlQuery(sql);
+	q1=new RDSqlQuery(sql);
 	delete q1;
       }
       delete q;
@@ -268,7 +268,7 @@ void ListClocks::addData()
                              CLOCK_NAME=\"%s\",SERVICE_NAME=\"%s\"",
 			    (const char *)clockname,
 			    (const char *)edit_filter_box->currentText());
-      q=new QSqlQuery(sql);
+      q=new RDSqlQuery(sql);
       delete q;
     }
   }
@@ -338,8 +338,8 @@ void ListClocks::deleteData()
 void ListClocks::renameData()
 {
   QString sql;
-  QSqlQuery *q;
-  QSqlQuery *q1;
+  RDSqlQuery *q;
+  RDSqlQuery *q1;
   QListViewItem *item=edit_clocks_list->selectedItem();
   if(item==NULL) {
     return;
@@ -357,14 +357,14 @@ void ListClocks::renameData()
   // Rename Grid References
   //
   sql="select NAME from SERVICES";
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     for(int i=0;i<168;i++) {
       sql=QString().sprintf("update SERVICES set CLOCK%d=\"%s\"\
                              where CLOCK%d=\"%s\"",
 			    i,(const char *)new_name,
 			    i,(const char *)item->text(0));
-      q1=new QSqlQuery(sql);
+      q1=new RDSqlQuery(sql);
       delete q1;
     }
   }
@@ -380,12 +380,12 @@ void ListClocks::renameData()
   sql=QString().sprintf("alter table %s_CLK rename to %s_CLK",
 			(const char *)old_name_esc,
 			(const char *)new_name_esc);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
   sql=QString().sprintf("alter table %s_RULES rename to %s_RULES",
 			(const char *)old_name_esc,
 			(const char *)new_name_esc);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 
   //
@@ -395,7 +395,7 @@ void ListClocks::renameData()
                          where CLOCK_NAME=\"%s\"",
 			(const char *)new_name,
 			(const char *)item->text(0));
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 
   //
@@ -404,7 +404,7 @@ void ListClocks::renameData()
   sql=QString().sprintf("update CLOCKS set NAME=\"%s\" where NAME=\"%s\"",
 			(const char *)new_name,
 			(const char *)item->text(0));
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 
   item->setText(0,new_name);
@@ -481,7 +481,7 @@ void ListClocks::RefreshList()
   edit_clocks_list->clear();
   QString sql=QString().sprintf("select NAME,SHORT_NAME,COLOR from CLOCKS %s",
 				(const char *)filter);
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   QListViewItem *item=NULL;
   while(q->next()) {
     item=new QListViewItem(edit_clocks_list);
@@ -512,7 +512,7 @@ void ListClocks::UpdateItem(QListViewItem *item,QString name)
 {
   QString sql=QString().sprintf("select NAME,SHORT_NAME,COLOR from CLOCKS\
                                  where NAME=\"%s\"",(const char *)name);
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   if(q->next()) {
     item->setText(0,name);
     WriteItem(item,q);
@@ -521,7 +521,7 @@ void ListClocks::UpdateItem(QListViewItem *item,QString name)
 }
 
 
-void ListClocks::WriteItem(QListViewItem *item,QSqlQuery *q)
+void ListClocks::WriteItem(QListViewItem *item,RDSqlQuery *q)
 {
   QPixmap *pix;
   QPainter *p=new QPainter();
@@ -542,11 +542,11 @@ int ListClocks::ActiveClocks(QString clockname,QString *svc_list)
 {
   int n=0;
   QString sql;
-  QSqlQuery *q,*q1;
+  RDSqlQuery *q,*q1;
   QString svcname;
 
   sql="select NAME from SERVICES";
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     sql=QString().sprintf("select NAME from SERVICES where (NAME=\"%s\")&&",
 			  (const char *)q->value(0).toString());
@@ -554,7 +554,7 @@ int ListClocks::ActiveClocks(QString clockname,QString *svc_list)
       sql+=QString().sprintf("(CLOCK%d=\"%s\")||",i,(const char *)clockname);
     }
     sql+=QString().sprintf("(CLOCK167=\"%s\")",(const char *)clockname);
-    q1=new QSqlQuery(sql);
+    q1=new RDSqlQuery(sql);
     if(q1->first()) {
       n++;
       *svc_list+=
@@ -569,7 +569,7 @@ int ListClocks::ActiveClocks(QString clockname,QString *svc_list)
 void ListClocks::DeleteClock(QString clockname)
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString base_name=clockname;
   base_name.replace(" ","_");
 
@@ -580,7 +580,7 @@ void ListClocks::DeleteClock(QString clockname)
     sql=QString().sprintf("update SERVICES set CLOCK%d=NULL\
                              where CLOCK%d=\"%s\"",
 			  i,i,(const char *)clockname);
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     delete q;
   }
 
@@ -589,7 +589,7 @@ void ListClocks::DeleteClock(QString clockname)
   //
   sql=QString().sprintf("delete from CLOCK_PERMS where CLOCK_NAME=\"%s\"",
 			(const char *)clockname);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 
   //
@@ -597,13 +597,13 @@ void ListClocks::DeleteClock(QString clockname)
   //
   sql=QString().sprintf("delete from CLOCKS where NAME=\"%s\"",
 				(const char *)clockname);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
   sql=QString().sprintf("drop table %s_CLK",(const char *)base_name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
   sql=QString().sprintf("drop table %s_RULES",(const char *)base_name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 }
 
@@ -614,7 +614,7 @@ QString ListClocks::GetClockFilter(QString svc_name)
   QString sql=QString().sprintf("select CLOCK_NAME from CLOCK_PERMS\
                                  where SERVICE_NAME=\"%s\"",
 				(const char *)svc_name);
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   if(q->size()>0) {
     while(q->next()) {
       filter+=QString().sprintf("(NAME=\"%s\")||",
@@ -634,11 +634,11 @@ QString ListClocks::GetClockFilter(QString svc_name)
 QString ListClocks::GetNoneFilter()
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString filter;
 
   sql="select CLOCK_NAME from CLOCK_PERMS";
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   if(q->size()>0) {
     filter="where ";
   }
