@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: list_grids.cpp,v 1.5 2007/09/14 14:06:58 fredg Exp $
+//      $Id: list_grids.cpp,v 1.6 2007/10/04 20:53:39 dmills Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -25,8 +25,8 @@
 #include <qtextedit.h>
 #include <qpainter.h>
 #include <qmessagebox.h>
-#include <qsqldatabase.h>
 
+#include <rddb.h>
 #include <rd.h>
 #include <rdevent.h>
 #include <rdcreate_log.h>
@@ -134,7 +134,7 @@ void ListGrids::RefreshList()
 
   edit_grids_list->clear();
   QString sql="select NAME,DESCRIPTION from SERVICES";
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   QListViewItem *item=NULL;
   while(q->next()) {
     item=new QListViewItem(edit_grids_list);
