@@ -173,6 +173,11 @@ Do you want to save?</source>
         <source>You must specify a clock code!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Scheduler
+Rules</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditEvent</name>
@@ -470,6 +475,30 @@ Do you want to overwrite it?</source>
         <source>, Inline Traffic</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Select from:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title Separation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Must have code</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>, Scheduler</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Overlap</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OVERLAP</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditEventLine</name>
@@ -576,6 +605,62 @@ already existing event.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>EditSchedRules</name>
+    <message>
+        <source>&amp;Edit</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Import</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;OK</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>CODE</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>MAX. IN A ROW</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>MIN. WAIT</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>DO NOT SCHEDULE AFTER</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OR AFTER</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>DESCRIPTION</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scheduler Codes:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rules Modified</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The rules have been modified.
+Do you want to save?</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>EditTrack</name>
     <message>
@@ -762,6 +847,14 @@ will remove this data.  Remerge?</source>
         <source>Edit Voice Track</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Set OVERLAP Transition</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OVERLAP</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ListClocks</name>
@@ -1005,10 +1098,6 @@ Reports</source>
         <source>Can&apos;t Connect</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Unable to connect to mySQL Server!</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>RDLogManager</source>
         <translation type="unfinished"></translation>
@@ -1176,4 +1265,35 @@ Data</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>editSchedCodeRules</name>
+    <message>
+        <source>&amp;OK</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Code:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Max. in a row:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Min. wait:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Do not schedule after:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Or after:</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 </TS>
