@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdpanel.cpp,v 1.13 2007/09/14 14:06:59 fredg Exp $
+//      $Id: rdpanel.cpp,v 1.15 2007/12/31 18:49:12 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -22,6 +22,9 @@
 
 #include <stdlib.h>
 #include <math.h>
+#include <sys/types.h>
+#include <sys/wait.h>
+#include <signal.h>
 
 #include <qmessagebox.h>
 #include <qapplication.h>
@@ -41,6 +44,7 @@ RDAirPlayConf *rdairplay_conf;
 RDAudioPort *rdaudioport_conf;
 RDUser *rduser;
 RDRipc *rdripc;
+RDCartDialog *panel_cart_dialog;
 
 //
 // Icons
@@ -48,6 +52,22 @@ RDRipc *rdripc;
 #include "../icons/rivendell-22x22.xpm"
 
 
+void SigHandler(int signo)
+{
+  pid_t pLocalPid;
+
+  switch(signo) {
+  case SIGCHLD:
+    pLocalPid=waitpid(-1,NULL,WNOHANG);
+    while(pLocalPid>0) {
+      pLocalPid=waitpid(-1,NULL,WNOHANG);
+    }
+    signal(SIGCHLD,SigHandler);
+    return;
+  }
+}
+
+
 MainWidget::MainWidget(QWidget *parent,const char *name)
   :QWidget(parent,name)
 {
@@ -150,6 +170,16 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   panel_player=new RDEventPlayer(rdripc,this);
 
+  //
+  // Cart Picker
+  //
+  panel_cart_dialog=new RDCartDialog(&panel_filter,&panel_group,
+				     rdairplay_conf->card(3),
+				     rdairplay_conf->port(3),
+				     0,0,panel_cae,rdripc,rdstation_conf,
+				     rdstation_conf->editorPath(),
+				     this,"panel_cart_dialog");
+
   //
   // Sound Panel Array
   //
@@ -162,7 +192,8 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
 		       rdairplay_conf->panels(RDAirPlayConf::UserPanel),
 		       rdairplay_conf->flashPanel(),
 		       rdairplay_conf->buttonLabelTemplate(),true,panel_player,
-		       rdripc,panel_cae,rdstation_conf,this,"panel_panel");
+		       rdripc,panel_cae,rdstation_conf,panel_cart_dialog,
+		       this,"panel_panel");
     panel_panel->setLogfile(panel_config->airplayLogname());
     panel_panel->setGeometry(10,10,panel_panel->sizeHint().width(),
 			 panel_panel->sizeHint().height());
@@ -246,6 +277,11 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   if(panel_config->useStreamMeters()) {
     panel_stereo_meter->hide();
   }
+
+  //
+  // Signal Handlers
+  //
+  signal(SIGCHLD,SigHandler);
 }
 
 
